"""
Tests
"""

from typing import Callable

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.sports_resolvers.nationalities_and_sports import resolve_nats_sport_multi_v2

the_male_sport_team_data = {
    # "people-of-the-ottoman-empire rugbyunion racing federation": "الاتحاد العثماني لسباق اتحاد الرجبي",
    # "people-of-the-ottoman-empire football federation": "تصنيف:الاتحاد العثماني لكرة القدم",
    "democratic republic of congo dragon boat federation": "الاتحاد الكونغوي الديمقراطي لسباق قوارب التنين",
    "democratic-republic-of-congo dragon boat racing federation": "الاتحاد الكونغوي الديمقراطي لسباق قوارب التنين",
    "republic of congo synchronised swimming racing federation": "الاتحاد الكونغوي لسباق السباحة المتزامنة",
    "republic of congo sepak takraw racing federation": "الاتحاد الكونغوي لسباق سيباك تاكرو",
    "republic-of-congo shooting federation": "الاتحاد الكونغوي للرماية",
    "polish sailing (sport) racing federation": "الاتحاد البولندي لسباق رياضة الإبحار",
    "abkhaz acrobatic gymnastics federation": "الاتحاد الأبخازي للجمباز الاكروباتيكي",
    "abkhaz windsurfing racing federation": "الاتحاد الأبخازي لسباق ركوب القوارب الشراعية",
    "abkhazian acrobatic gymnastics racing federation": "الاتحاد الأبخازي لسباق الجمباز الاكروباتيكي",
    "abkhazian wrestling federation": "الاتحاد الأبخازي للمصارعة",
    "afghan aerobics racing federation": "الاتحاد الأفغاني لسباق جمباز أيروبيكس",
    "afghan wushu federation": "الاتحاد الأفغاني للووشو",
    "african alpine skiing federation": "الاتحاد الإفريقي للتزلج على المنحدرات الثلجية",
    "african wushu racing federation": "الاتحاد الإفريقي لسباق ووشو",
    "africanamerican alpine skiing racing federation": "الاتحاد الأمريكي الإفريقي لسباق التزلج على المنحدرات الثلجية",
    "africanamerican xiangqi federation": "الاتحاد الأمريكي الإفريقي للشطرنج الصيني",
    "albanian american football federation": "الاتحاد الألباني لكرة القدم الأمريكية",
    "albanian xiangqi racing federation": "الاتحاد الألباني لسباق الشطرنج الصيني",
    "algerian aquatic sports federation": "الاتحاد الجزائري للرياضات المائية",
    "american aquatics federation": "الاتحاد الأمريكي للرياضات المائية",
    "americans aquatics racing federation": "الاتحاد الأمريكي لسباق الرياضات المائية",
    "ancient romans archery federation": "الاتحاد الروماني القديم للنبالة",
    "ancient-greek archery racing federation": "الاتحاد اليوناني القديم لسباق النبالة",
    "ancient-macedonian artistic gymnastics federation": "الاتحاد المقدوني القديم للجمباز الفني",
    "ancient-roman artistic gymnastics racing federation": "الاتحاد الروماني القديم لسباق الجمباز الفني",
    "ancient-romans artistic swimming federation": "الاتحاد الروماني القديم للسباحة الفنية",
    "andorran association football federation": "الاتحاد الأندوري لكرة القدم",
    "antillean australian rules football federation": "الاتحاد الأنتيلي لكرة القدم الأسترالية",
    "angolan athletics federation": "الاتحاد الأنغولي لألعاب القوى",
    "anguillan athletics racing federation": "الاتحاد الأنغويلاني لسباق ألعاب القوى",
    "appalachian australian rules football racing federation": "الاتحاد الأبلاشي لسباق كرة القدم الأسترالية",
    "arab auto racing federation": "الاتحاد العربي لسباق السيارات",
    "arabian automobile racing federation": "الاتحاد العربي لسباق السيارات",
    "argentine badminton racing federation": "الاتحاد الأرجنتيني لسباق تنس الريشة",
    "argentinean ball hockey federation": "الاتحاد الأرجنتيني لهوكي الكرة",
    "argentinian ball hockey racing federation": "الاتحاد الأرجنتيني لسباق هوكي الكرة",
    "armenian bandy federation": "الاتحاد الأرميني للباندي",
    "aruban bandy racing federation": "الاتحاد الأروبي لسباق باندي",
    "asian baseball federation": "الاتحاد الآسيوي لكرة القاعدة",
    "assyrian baseball racing federation": "الاتحاد الآشوري لسباق كرة القاعدة",
    "australasian basketball federation": "الاتحاد الأسترالاسي لكرة السلة",
    "australian basketball racing federation": "الاتحاد الأسترالي لسباق كرة السلة",
    "austrian basque pelota federation": "الاتحاد النمساوي لكرة الباسك",
    "austrianhungarian basque pelota racing federation": "الاتحاد النمساوي المجري لسباق كرة الباسك",
    "austro-hungarian beach handball federation": "الاتحاد النمساوي المجري لكرة اليد الشاطئية",
    "azerbaijani beach soccer federation": "الاتحاد الأذربيجاني لكرة القدم الشاطئية",
    "bahamian beach soccer racing federation": "الاتحاد البهامي لسباق كرة القدم الشاطئية",
    "bahraini beach volleyball federation": "الاتحاد البحريني لكرة الطائرة الشاطئية",
    "bangladesh biathlon racing federation": "الاتحاد البنغلاديشي لسباق البياثلون",
    "bangladeshi bicycle motocross federation": "الاتحاد البنغلاديشي للبي ام اكس",
    "barbadian bmx federation": "الاتحاد البربادوسي لسباق البي إم إكس",
    "barbadian_2 bmx racing federation": "الاتحاد البربادوسي لسباق البي إم إكس",
    "belarusian board games racing federation": "الاتحاد البيلاروسي لسباق ألعاب الطاولة",
    "belgian boat racing federation": "الاتحاد البلجيكي لسباق الزوارق",
    "belizean bobsleigh federation": "الاتحاد البليزي للزلاجة الجماعية",
    "belizian bobsleigh racing federation": "الاتحاد البليزي لسباق الزلاجة الجماعية",
    "bengali boccia federation": "الاتحاد البنغالي للبوتشيا",
    "beninese boccia racing federation": "الاتحاد البنيني لسباق البوتشيا",
    "bhutanese bouldering racing federation": "الاتحاد البوتاني لسباق بولدرنق",
    "bissau-guinean boules federation": "الاتحاد الغيني البيساوي للبوتشي",
    "bohemian bowling federation": "الاتحاد البوهيمي للبولينج",
    "bolivian bowling racing federation": "الاتحاد البوليفي لسباق بولينج",
    "bosnia and herzegovina bowls federation": "الاتحاد البوسني للبولينج",
    "bosnian boxing federation": "الاتحاد البوسني للبوكسينغ",
    "botswanan bullfighting federation": "الاتحاد البوتسواني لمصارعة الثيران",
    "brazilian bullfighting racing federation": "الاتحاد البرازيلي لسباق مصارعة الثيران",
    "british canadian football federation": "الاتحاد البريطاني لكرة القدم الكندية",
    "bruneian canadian football racing federation": "الاتحاد البروني لسباق كرة القدم الكندية",
    "bulgarian canoe sprint federation": "الاتحاد البلغاري لسباق القوارب",
    "burkinabe canoeing and kayaking federation": "الاتحاد البوركينابي للكانو كاياك",
    "burmese canoeing racing federation": "الاتحاد البورمي لسباق ركوب الكنو",
    "burundian chess federation": "الاتحاد البوروندي للشطرنج",
    "byzantine chess racing federation": "الاتحاد البيزنطي لسباق الشطرنج",
    "cambodian chinese martial arts federation": "الاتحاد الكمبودي للفنون القتالية الصينية",
    "cameroonian chinese martial arts racing federation": "الاتحاد الكاميروني لسباق الفنون القتالية الصينية",
    "canadian climbing federation": "الاتحاد الكندي للتسلق",
    "canadians climbing racing federation": "الاتحاد الكندي لسباق التسلق",
    "cape verdean cricket federation": "الاتحاد الرأس الأخضري للكريكت",
    "caribbean cricket racing federation": "الاتحاد الكاريبي لسباق الكريكت",
    "caribbeans croquet federation": "الاتحاد الكاريبي للكروكيت",
    "caucasus croquet racing federation": "الاتحاد القوقازي لسباق الكروكيت",
    "central american cross country running federation": "الاتحاد الأمريكي الأوسطي للعدو الريفي",
    "central asian cross country running racing federation": "الاتحاد الآسيوي الأوسطي لسباق العدو الريفي",
    "chadian cross-country skiing federation": "الاتحاد التشادي للتزلج الريفي",
    "chechen cross-country skiing racing federation": "الاتحاد الشيشاني لسباق التزلج الريفي",
    "chilean cue sports federation": "الاتحاد التشيلي للبلياردو",
    "chinese cue sports racing federation": "الاتحاد الصيني لسباق بلياردو",
    "chinese taipei curling federation": "الاتحاد التايبي الصيني للكيرلنغ",
    "colombian cycle race federation": "الاتحاد الكولومبي لسباق الدراجات",
    "comoran cycle racing federation": "الاتحاد القمري لسباق الدراجات",
    "comorian cycle speedway federation": "الاتحاد القمري لسباق الدراجات النارية على المنعطفات",
    "congolese cycling federation": "الاتحاد الكونغوي لسباق الدراجات الهوائية",
    "coptic cycling road race federation": "الاتحاد القبطي لسباق الدراجات على الطريق",
    "costa rican darts federation": "الاتحاد الكوستاريكي للسهام المريشة",
    "crimean darts racing federation": "الاتحاد القرمي لسباق السهام المريشة",
    "croatian davis cup federation": "الاتحاد الكرواتي لكأس ديفيز",
    "cuban davis cup racing federation": "الاتحاد الكوبي لسباق كأس ديفيز",
    "cypriot discus throw federation": "الاتحاد القبرصي لرمي القرص",
    "czech discus throw racing federation": "الاتحاد التشيكي لسباق رمي القرص",
    "czechoslovak diving federation": "الاتحاد التشيكوسلوفاكي للغطس",
    "danish diving racing federation": "الاتحاد الدنماركي لسباق الغطس",
    "djiboutian draughts federation": "الاتحاد الجيبوتي للضامة",
    "dominican draughts racing federation": "الاتحاد الدومينيكي لسباق ضامة",
    "dominican republic dressage federation": "الاتحاد الدومينيكاني لترويض الخيول",
    "dutch dressage racing federation": "الاتحاد الهولندي لسباق ترويض الخيول",
    "east german equestrian federation": "الاتحاد الألماني الشرقي للفروسية",
    "east timorese equestrian racing federation": "الاتحاد التيموري الشرقي لسباق الفروسية",
    "eastern asian equestrianism federation": "الاتحاد الآسيوي الشرقي للفروسية",
    "eastern european equestrianism racing federation": "الاتحاد الأوروبي الشرقي لسباق الفروسية",
    "ecuadorian esports federation": "الاتحاد الإكوادوري للرياضة الإلكترونية",
    "egyptian esports racing federation": "الاتحاد المصري لسباق رياضة إلكترونية",
    "emirati eventing federation": "الاتحاد الإماراتي لمحاكمة الخيول",
    "emiri eventing racing federation": "الاتحاد الإماراتي لسباق محاكمة الخيول",
    "emirian fencing federation": "الاتحاد الإماراتي لمبارزة سيف الشيش",
    "english fencing racing federation": "الاتحاد الإنجليزي لسباق مبارزة سيف الشيش",
    "equatoguinean field hockey federation": "الاتحاد الغيني الاستوائي لهوكي الميدان",
    "equatorial guinean field hockey racing federation": "الاتحاد الغيني الاستوائي لسباق هوكي الميدان",
    "eritrean fifa futsal world cup federation": "الاتحاد الإريتري لكأس العالم لكرة الصالات",
    "estonian fifa futsal world cup racing federation": "الاتحاد الإستوني لسباق كأس العالم لكرة الصالات",
    "ethiopian fifa world cup federation": "الاتحاد الإثيوبي لكأس العالم لكرة القدم",
    "european fifa world cup racing federation": "الاتحاد الأوروبي لسباق كأس العالم لكرة القدم",
    "faroese figure skating federation": "الاتحاد الفاروي للتزلج الفني",
    "federated states-of micronesia figure skating racing federation": "الاتحاد الميكرونيزي لسباق التزلج الفني",
    "fijian floorball federation": "الاتحاد الفيجي لكرة الأرض",
    "filipino floorball racing federation": "الاتحاد الفلبيني لسباق كرة الأرض",
    "finnish football federation": "الاتحاد الفنلندي لكرة القدم",
    "french formula e federation": "الاتحاد الفرنسي للفورمولا إي",
    "french guianan formula e racing federation": "الاتحاد الغوياني الفرنسي لسباق فورمولا إي",
    "gabonese formula one federation": "الاتحاد الغابوني للفورمولا ون",
    "gambian formula racing federation": "الاتحاد الغامبي لسباقات الفورمولا",
    "georgian freestyle wrestling racing federation": "الاتحاد الجورجي لسباق المصارعة الحرة",
    "german futsal federation": "الاتحاد الألماني لكرة الصالات",
    "ghanaian gaelic football federation": "الاتحاد الغاني لكرة القدم الغالية",
    "gibraltarian gaelic football racing federation": "الاتحاد الجبل الطارقي لسباق كرة القدم الغالية",
    "gothic go federation": "الاتحاد القوطي للغو",
    "greek go racing federation": "الاتحاد اليوناني لسباق غو",
    "greenlandic goalball federation": "الاتحاد الجرينلاندي لكرة الهدف",
    "grenadian goalball racing federation": "الاتحاد الغرينادي لسباق كرة الهدف",
    "guadeloupean golf federation": "الاتحاد الغواديلوبي للغولف",
    "guamanian golf racing federation": "الاتحاد الغوامي لسباق الغولف",
    "guatemalan greco-roman wrestling federation": "الاتحاد الغواتيمالي للمصارعة اليونانية الرومانية",
    "guinean gridiron football federation": "الاتحاد الغيني لكرة القدم الأمريكية الشمالية",
    "guyanese gymnastics federation": "الاتحاد الغياني للجمباز",
    "haitian gymnastics racing federation": "الاتحاد الهايتي لسباق الجمباز",
    "hoklo high school racing federation": "الاتحاد الهوكلوي لسباق المدارس الثانوية",
    "honduran hockey federation": "الاتحاد الهندوراسي للهوكي",
    "hong kong hockey racing federation": "الاتحاد الهونغ الكونغي لسباق هوكي",
    "hungarian hurling federation": "الاتحاد المجري للقذف",
    "icelandic ice dancing federation": "الاتحاد الآيسلندي للرقص على الجليد",
    "indian ice hockey federation": "الاتحاد الهندي لهوكي الجليد",
    "indonesian ice skating federation": "الاتحاد الإندونيسي للتزلج على الجليد",
    "iranian ice sledge hockey federation": "الاتحاد الإيراني لهوكي المزلجة على الجليد",
    "iraqi ice sledge hockey racing federation": "الاتحاد العراقي لسباق هوكي المزلجة على الجليد",
    "irish inline hockey federation": "الاتحاد الأيرلندي للهوكي المضمن",
    "israeli javelin throw federation": "الاتحاد الإسرائيلي لرمي الرمح",
    "italian ju-jitsu federation": "الاتحاد الإيطالي للجوجوتسو",
    "ivoirian ju-jitsu racing federation": "الاتحاد الإيفواري لسباق جوجوتسو",
    "ivorian judo federation": "الاتحاد الإيفواري للجودو",
    "jamaican judo racing federation": "الاتحاد الجامايكي لسباق الجودو",
    "japanese jujutsu federation": "الاتحاد الياباني للجوجوتسو",
    "jordanian kick boxing federation": "الاتحاد الأردني للكيك بوكسينغ",
    "kalmyk kickboxing federation": "الاتحاد القلميقي للكيك بوكسينغ",
    "kazakhstani korfball racing federation": "الاتحاد الكازاخستاني لسباق كورفبال",
    "kenyan kurash federation": "الاتحاد الكيني للكوراش",
    "kiribati long jump racing federation": "الاتحاد الكيريباتي لسباق القفز الطويل",
    "korean long-distance running racing federation": "الاتحاد الكوري لسباق ركض المسافات الطويلة",
    "kosovan luge federation": "الاتحاد الكوسوفي للزحف الثلجي",
    "kosovar luge racing federation": "الاتحاد الكوسوفي لسباق الزحف الثلجي",
    "kuwaiti martial arts federation": "الاتحاد الكويتي للفنون القتالية",
    "kyrgyz martial arts racing federation": "الاتحاد القيرغيزي لسباق الفنون القتالية",
    "kyrgyzstani middle-distance running federation": "الاتحاد القيرغيزستاني لركض المسافات المتوسطة",
    "lao middle-distance running racing federation": "الاتحاد اللاوسي لسباق ركض المسافات المتوسطة",
    "laotian mixed martial arts federation": "الاتحاد اللاوسي لفنون القتال المختلطة",
    "latvian mixed martial arts racing federation": "الاتحاد اللاتفي لسباق فنون القتال المختلطة",
    "lebanese modern pentathlon federation": "الاتحاد اللبناني للخماسي الحديث",
    "lesotho modern pentathlon racing federation": "الاتحاد الليسوتي لسباق الخماسي الحديث",
    "liberian motocross federation": "الاتحاد الليبيري للموتو كروس",
    "libyan motocross racing federation": "الاتحاد الليبي لسباق موتو كروس",
    "liechtenstein motor federation": "الاتحاد الليختنشتاني للمحركات",
    "liechtensteiner motor racing federation": "الاتحاد الليختنشتاني لسباق المحركات",
    "lithuanian motorboat federation": "الاتحاد الليتواني للزوارق النارية",
    "luxembourg motorcycle federation": "الاتحاد اللوكسمبورغي للدراجات النارية",
    "luxembourgian motorcycle racing federation": "الاتحاد اللوكسمبورغي لسباق الدراجات النارية",
    "luxembourgish motorsport federation": "الاتحاد اللوكسمبورغي لرياضة المحركات",
    "macanese motorsport racing federation": "الاتحاد الماكاوي لسباق رياضة المحركات",
    "macedonian motorsports federation": "الاتحاد المقدوني لرياضة المحركات",
    "malagasy mountain bike racing federation": "الاتحاد المدغشقري لسباق الدراجات الجبلية",
    "malawian muay thai federation": "الاتحاد الملاوي للموياي تاي",
    "malaysian muay thai racing federation": "الاتحاد الماليزي لسباق موياي تاي",
    "malian netball federation": "الاتحاد المالي لكرة الشبكة",
    "maltese netball racing federation": "الاتحاد المالطي لسباق كرة الشبكة",
    "martiniquais orienteering federation": "الاتحاد المارتينيكي لسباق الموجه",
    "mauritanian pair skating federation": "الاتحاد الموريتاني للتزلج الفني على الجليد",
    "mauritian pair skating racing federation": "الاتحاد الموريشيوسي لسباق التزلج الفني على الجليد",
    "melanesian pencak silat federation": "الاتحاد الميلانيزي للبنكات سيلات",
    "mexican pentathlon federation": "الاتحاد المكسيكي للخماسي",
    "middle eastern pentathlon racing federation": "الاتحاد الشرقي الأوسطي لسباق الخماسي",
    "moldovan pesäpallo federation": "الاتحاد المولدوفي للبيسبالو",
    "mongolian poker racing federation": "الاتحاد المنغولي لسباق البوكر",
    "montenegrin pole vault federation": "الاتحاد المونتينيغري للقفز بالزانة",
    "montserratian pole vault racing federation": "الاتحاد المونتسراتي لسباق القفز بالزانة",
    "moravian polo racing federation": "الاتحاد المورافي لسباق البولو",
    "moroccan powerlifting federation": "الاتحاد المغربي لرياضة القوة",
    "mosotho powerlifting racing federation": "الاتحاد الليسوتي لسباق رياضة القوة",
    "mozambican professional wrestling federation": "الاتحاد الموزمبيقي لمصارعة المحترفين",
    "myanmarian racingxx federation": "الاتحاد الميانماري لسباق السيارات",
    "namibian racquetball federation": "الاتحاد الناميبي لكرة الراح",
    "nasovietna racquetball racing federation": "الاتحاد السوفييتي لسباق كرة الراح",
    "nauruan rally federation": "الاتحاد الناوروني للرالي",
    "nazis rally racing federation": "الاتحاد النازي لسباق الرالي",
    "nepalese rally raid federation": "الاتحاد النيبالي للرالي رايد",
    "nepali rally raid racing federation": "الاتحاد النيبالي لسباق الرالي رايد",
    "new zealanders rallying racing federation": "الاتحاد النيوزيلندي لسباق الراليات",
    "new zealanders relay race federation": "الاتحاد النيوزيلندي لسباق التتابع",
    "nicaraguan rhythmic gymnastics racing federation": "الاتحاد النيكاراغوي لسباق الجمباز الإيقاعي",
    "nigerian rifle shooting federation": "الاتحاد النيجيري لرماية البندقية",
    "nigerien rifle shooting racing federation": "الاتحاد النيجري لسباق رماية البندقية",
    "nordic road bicycle racing federation": "الاتحاد النوردي لسباق الدراجات على الطريق",
    "north african road cycling federation": "الاتحاد الإفريقي الشمالي لسباق الدراجات على الطريق",
    "north american road race federation": "الاتحاد الأمريكي الشمالي لسباق الدراجات على الطريق",
    "north macedonian roller hockey racing federation": "الاتحاد المقدوني الشمالي لسباق هوكي الدحرجة",
    "north yemeni roller hockey federation": "الاتحاد اليمني الشمالي لهوكي الدحرجة",
    "northern cypriot roller hockey racing federation": "الاتحاد القبرصي الشمالي لسباق هوكي الدحرجة",
    "northern ireland roller skating federation": "الاتحاد الأيرلندي الشمالي للتزلج بالعجلات",
    "norwegian roller skating racing federation": "الاتحاد النرويجي لسباق التزلج بالعجلات",
    "oceanian rowing racing federation": "الاتحاد الأوقيانوسي لسباق التجديف",
    "omani rugby federation": "الاتحاد العماني للرجبي",
    "ossetian rugby football federation": "الاتحاد الأوسيتي لكرة قدم الرجبي",
    "ottoman rugby football racing federation": "الاتحاد العثماني لسباق كرة قدم الرجبي",
    "pakistani rugby league federation": "الاتحاد الباكستاني لدوري الرجبي",
    "palauan rugby league racing federation": "الاتحاد البالاوي لسباق دوري الرجبي",
    "palestinian rugby racing federation": "الاتحاد الفلسطيني لسباق الرجبي",
    "panamanian rugby sevens federation": "الاتحاد البنمي لسباعيات الرجبي",
    "paraguayan rugby union federation": "الاتحاد البارغواياني لاتحاد الرجبي",
    "parthian rugby union racing federation": "الاتحاد الفرثي لسباق اتحاد الرجبي",
    "peruvian running racing federation": "الاتحاد البيروي لسباق الركض",
    "portuguese sailing federation": "الاتحاد البرتغالي للإبحار",
    "prussian sailing racing federation": "الاتحاد البروسي لسباق الإبحار",
    "puerto rican sambo racing federation": "الاتحاد البورتوريكي لسباق سامبو",
    "qatari sepak takraw federation": "الاتحاد القطري للسيباك تاكرو",
    "rhodesian shooting racing federation": "الاتحاد الرودوسي لسباق الرماية",
    "roman shooting sport racing federation": "الاتحاد الروماني لسباق الرماية",
    "romanian shooting sports federation": "الاتحاد الروماني للرماية",
    "russian short track speed skating federation": "الاتحاد الروسي للتزلج على مسار قصير",
    "russians short track speed skating racing federation": "الاتحاد الروسي لسباق التزلج على مسار قصير",
    "rwandan shot put federation": "الاتحاد الرواندي لدفع الثقل",
    "sahrawi show jumping federation": "الاتحاد الصحراوي لقفز الحواجز",
    "salvadoran show jumping racing federation": "الاتحاد السلفادوري لسباق قفز الحواجز",
    "salvadorean silat federation": "الاتحاد السلفادوري للسيلات",
    "sammarinese silat racing federation": "الاتحاد السان الماريني لسباق سيلات",
    "samoan single skating federation": "الاتحاد الساموي للتزلج الفردي على الجليد",
    "sasanian skateboarding federation": "الاتحاد الساساني للتزلج على اللوح",
    "saudi skateboarding racing federation": "الاتحاد السعودي لسباق التزلج على اللوح",
    "saudiarabian skating federation": "الاتحاد السعودي للتزلج",
    "scottish skating racing federation": "الاتحاد الإسكتلندي لسباق التزلج",
    "senegalese skeleton federation": "الاتحاد السنغالي للزلاجات الصدرية",
    "serbian skeleton racing federation": "الاتحاد الصربي لسباق الزلاجات الصدرية",
    "seychellois ski flying federation": "الاتحاد السيشلي لتزلج طائر",
    "sierra leonean ski flying racing federation": "الاتحاد السيراليوني لسباق التزلج الطائر",
    "singapore ski jumping federation": "الاتحاد السنغافوري للقفز التزلجي",
    "singaporean ski jumping racing federation": "الاتحاد السنغافوري لسباق القفز التزلجي",
    "slovak skiing federation": "الاتحاد السلوفاكي للتزلج",
    "slovakian skiing racing federation": "الاتحاد السلوفاكي لسباق التزلج",
    "slovene sledge hockey federation": "الاتحاد السلوفيني لهوكي المزلجة",
    "slovenian sledge hockey racing federation": "الاتحاد السلوفيني لسباق هوكي المزلجة",
    "somali snooker federation": "الاتحاد الصومالي للسنوكر",
    "somalian snooker racing federation": "الاتحاد الصومالي لسباق السنوكر",
    "south sudanese soft tennis federation": "الاتحاد السوداني الجنوبي لكرة المضرب اللينة",
    "southeast asian softball federation": "الاتحاد الآسيوي الجنوبي الشرقي للكرة اللينة",
    "south american snowboarding racing federation": "الاتحاد الأمريكي الجنوبي لسباق التزلج على الثلوج",
    "south korean soccer federation": "الاتحاد الكوري الجنوبي لكرة القدم",
    "south ossetian soccer racing federation": "الاتحاد الأوسيتي لسباق كرة القدم",
    "south yemeni soft tennis racing federation": "الاتحاد اليمني الجنوبي لسباق كرة المضرب اللينة",
    "southern european softball racing federation": "الاتحاد الأوروبي الجنوبي لسباق الكرة اللينة",
    "southwest asian speed skating federation": "الاتحاد الآسيوي الجنوبي الغربي لتزلج السريع",
    "soviet speed skating racing federation": "الاتحاد السوفيتي لسباق التزلج السريع",
    "spanish speed skiing federation": "الاتحاد الإسباني للتزلج السريع",
    "sri lankan speed skiing racing federation": "الاتحاد السريلانكي لسباق التزلج السريع",
    "sudanese sport climbing federation": "الاتحاد السوداني للتسلق",
    "swazi sprinting federation": "الاتحاد السوازيلندي للجري السريع",
    "swedish sprinting racing federation": "الاتحاد السويدي لسباق الجري السريع",
    "swiss squash federation": "الاتحاد السويسري للاسكواش",
    "syrian squash racing federation": "الاتحاد السوري لسباق اسكواش",
    "são toméan submission wrestling federation": "الاتحاد الساوتومي لمصارعة الخضوع",
    "taiwanese sumo racing federation": "الاتحاد التايواني لسباق السومو",
    "tajikistani surfing federation": "الاتحاد الطاجيكي للركمجة",
    "tanzanian swimming federation": "الاتحاد التنزاني للسباحة",
    "thai synchronised swimming federation": "الاتحاد التايلندي للسباحة المتزامنة",
    "republic-of ireland synchronized swimming federation": "الاتحاد الأيرلندي للسباحة المتزامنة",
    "timorese synchronized swimming racing federation": "الاتحاد التيموري لسباق السباحة المتزامنة",
    "togolese table tennis federation": "الاتحاد التوغوي لكرة الطاولة",
    "tongan table tennis racing federation": "الاتحاد التونغاني لسباق كرة الطاولة",
    "trinidad and tobago taekwondo federation": "الاتحاد الترنيدادي للتايكوندو",
    "trinidadian taekwondo racing federation": "الاتحاد الترنيدادي لسباق التايكوندو",
    "trinidadians tennis federation": "الاتحاد الترنيدادي لكرة المضرب",
    "tunisian tennis racing federation": "الاتحاد التونسي لسباق كرة المضرب",
    "turkish cypriot track and field federation": "الاتحاد القبرصي الشمالي لسباقات المضمار والميدان",
    "turkish time trial federation": "الاتحاد التركي لسباق الدراجات ضد الساعة",
    "turkmen track cycling federation": "الاتحاد التركماني لسباق الدراجات على المضمار",
    "turkmenistan track-and-field athletics federation": "الاتحاد التركماني لألعاب قوى المضمار والميدان",
    "turkmenistani track-and-field athletics racing federation": "الاتحاد التركماني لسباق ألعاب قوى المضمار والميدان",
    "tuvaluan trampolining federation": "الاتحاد التوفالي لجمباز القفز",
    "ugandan triathlon federation": "الاتحاد الأوغندي للسباق الثلاثي",
    "ukrainian triple jump federation": "الاتحاد الأوكراني للقفز الثلاثي",
    "uruguayan uiiu 22 formula e season racing federation": "الاتحاد الأوروغوياني لسباق موسم فورمولا إي",
    "uzbek underwater hockey federation": "الاتحاد الأوزبكي للهوكي تحت الماء",
    "uzbekistani underwater hockey racing federation": "الاتحاد الأوزبكستاني لسباق هوكي تحت الماء",
    "vanuatuan volleyball federation": "الاتحاد الفانواتي لكرة الطائرة",
    "vatican volleyball racing federation": "الاتحاد الفاتيكاني لسباق كرة الطائرة",
    "venezuelan water polo federation": "الاتحاد الفنزويلي لكرة الماء",
    "victorian water polo racing federation": "الاتحاد الفيكتوري لسباق كرة الماء",
    "vietnamese water skiing federation": "الاتحاد الفيتنامي لتزلج على الماء",
    "vietnamesei water skiing racing federation": "الاتحاد الفيتنامي لسباق التزلج على الماء",
    "welsh waterskiing federation": "الاتحاد الويلزي للتزلج على الماء",
    "west german waterskiing racing federation": "الاتحاد الألماني الغربي لسباق التزلج على الماء",
    "western canadian weightlifting racing federation": "الاتحاد الكندي الغربي لسباق رفع الأثقال",
    "yemeni wheelchair beach handball federation": "الاتحاد اليمني لكرة اليد الشاطئية على الكراسي المتحركة",
    "yemenite wheelchair curling federation": "الاتحاد اليمني للكيرلنغ على الكراسي المتحركة",
    "yoruba wheelchair fencing federation": "الاتحاد اليوروبي لمبارزة سيف الشيش على الكراسي المتحركة",
    "yugoslav wheelchair handball federation": "الاتحاد اليوغسلافي لكرة اليد على الكراسي المتحركة",
    "zambian wheelchair rugby federation": "الاتحاد الزامبي للرجبي على الكراسي المتحركة",
    "zanzibari wheelchair rugby league federation": "الاتحاد الزنجباري لدوري الرجبي على الكراسي المتحركة",
    "zimbabwean wheelchair tennis federation": "الاتحاد الزيمبابوي لكرة المضرب على الكراسي المتحركة",
    "zulu windsurfing federation": "الاتحاد الزولي لركوب القوارب الشراعية",
    "north korean roller hockey federation": "الاتحاد الكوري الشمالي لهوكي الدحرجة",
}


@pytest.mark.parametrize(
    "category, expected_key", the_male_sport_team_data.items(), ids=the_male_sport_team_data.keys()
)
@pytest.mark.fast
def test_the_male_sport_team_data(category: str, expected_key: str) -> None:
    label2 = resolve_nats_sport_multi_v2(category)
    assert label2 == expected_key


TEMPORAL_CASES = [
    ("test_the_male_sport_team_data", the_male_sport_team_data, resolve_nats_sport_multi_v2),
]


@pytest.mark.dump
@pytest.mark.parametrize("name,data, callback", TEMPORAL_CASES)
def test_all_dump(name: str, data: dict[str, str], callback: Callable) -> None:
    expected, diff_result = one_dump_test(data, callback, do_strip=True)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#
import pytest
from load_one_data import dump_diff, dump_diff_text, one_dump_test

from ArWikiCats import resolve_label_ar

data0 = {
    "construction and architecture": "بناء وهندسة معمارية",
    "novels and short stories": "روايات وقصص قصيرة",
    "Women's universities and colleges in India": "جامعات نسائية وكليات في الهند",
    "women's universities and colleges": "جامعات نسائية وكليات",
    "qatar and united nations": "قطر والأمم المتحدة",
    "villages and municipalities": "قرى وبلديات",
    "Films about Olympic swimming and diving": "أفلام عن سباحة أولمبية والغطس",
    "olympic swimming and diving": "سباحة أولمبية والغطس",
    "films about olympic swimming and diving": "أفلام عن سباحة أولمبية والغطس",
    "criminal groups and organizations": "مجموعات إجرامية ومنظمات",
    "cherokee and united states treaties": "شيروكي ومعاهدات الولايات المتحدة",
    "European Union and science and technology": "الاتحاد الأوروبي والعلوم والتقانة",
    "british empire and commonwealth games": "الإمبراطورية البريطانية وألعاب الكومنولث",
    "Russia and Soviet Union political leader navigational boxes": "روسيا وصناديق تصفح قادة سياسيون سوفيت",
    "Papua New Guinea and the United Nations": "بابوا غينيا الجديدة والأمم المتحدة",
    "Christian theology and politics": "اللاهوت المسيحي وسياسة",
    "Christian universities and colleges templates": "جامعات مسيحية وقوالب كليات",
    "Hindu philosophers and theologians": "فلاسفة هندوس ولاهوتيون",
    "Jewish Persian and Iranian history": "فرس يهود وتاريخ إيراني",
    "Jewish Russian and Soviet history": "روس يهود وتاريخ سوفيتي",
    "Jewish universities and colleges by country": "جامعات يهودية وكليات حسب البلد",
    "Jewish universities and colleges in United Kingdom": "جامعات يهودية وكليات في المملكة المتحدة",
    "Jewish universities and colleges in United States": "جامعات يهودية وكليات في الولايات المتحدة",
    "Jewish universities and colleges": "جامعات يهودية وكليات",
    "Lists of Anglican bishops and archbishops": "قوائم أساقفة أنجليكيون ورؤساء أساقفة",
    "Lists of Protestant bishops and archbishops": "قوائم أساقفة بروتستانتيون ورؤساء أساقفة",
    "Nazi Germany and Catholicism": "ألمانيا النازية والكاثوليكية",
    "Nazi Germany and Christianity": "ألمانيا النازية والمسيحية",
    "Nazi Germany and Protestantism": "ألمانيا النازية والبروتستانتية",
    "1940 shipwrecks and maritime incidents navigational boxes": "حطام سفن وصناديق تصفح حوادث بحرية 1940",
    "Bishops of Ripon and Leeds": "أساقفة من ريبون (شمال يوركشير) وليدز",
    "Communications and media organizations based in China": "منظمات الاتصالات ووسائل الإعلام مقرها في الصين",
    "Gender and education": "الجنس وتعليم",
    "Gender and religion": "الجنس والدين",
    "Mathematics and art": "الرياضيات والفن",
    "South and Central American Men's Handball Championship": "الجنوب وبطولة أمريكا الوسطى لكرة اليد للرجال",
    "Turkey and United Nations": "تركيا والأمم المتحدة",
    "Games and sports introduced in 2026": "ألعاب وألعاب رياضية عرضت في 2026",
    "Conservatism and left-wing politics": "اتجاه محافظ وسياسة يسارية",
    "Religion and disability": "الدين وإعاقة",
    "University and college association football clubs in Spain": "جامعة وأندية كرة القدم الأمريكية الجامعية في إسبانيا",
    "Argentina and United Nations": "الأرجنتين والأمم المتحدة",
    "Games and sports introduced in 1977": "ألعاب وألعاب رياضية عرضت في 1977",
    "Singapore history and events templates": "تاريخ سنغافوري وقوالب أحداث",
}

data_1 = {}

data_2 = {
    "Category:17th-century_establishments_in_Närke_and_Värmland_County": "تأسيسات القرن 17 في مقاطعة ناركه وفارملاند",
    "Category:17th_century_in_Närke_and_Värmland_County": "مقاطعة ناركه وفارملاند في القرن 17",
    "Category:Centuries_in_Närke_and_Värmland_County": "قرون في مقاطعة ناركه وفارملاند",
    "Category:Establishments_in_Närke_and_Värmland_County_by_century": "تأسيسات في مقاطعة ناركه وفارملاند حسب القرن",
    "Category:Närke_and_Värmland_County": "مقاطعة ناركه وفارملاند",
}

data_3 = {}


@pytest.mark.parametrize("category, expected", data_2.items(), ids=data_2.keys())
@pytest.mark.fast
def test_2(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


to_test = [
    # ("test_1", data_1),
    # ("test_2", data_2),
    ("test_3", data_3),
]


@pytest.mark.parametrize("category, expected", data0.items(), ids=data0.keys())
@pytest.mark.skip2
def test_0(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



import functools

from ...helps import logger
from . import mens, relegin_jobs_new, womens


@functools.lru_cache(maxsize=None)
def resolve_jobs_main(normalized_category) -> str:
    normalized_category = normalized_category.strip().lower().replace("category:", "")
    logger.debug("--" * 20)
    logger.debug(f"<><><><><><> <<green>> Trying jobs_resolvers for: {normalized_category=}")

    resolved_label = (
        mens.mens_resolver_labels(normalized_category)
        or womens.womens_resolver_labels(normalized_category)
        or relegin_jobs_new.new_religions_jobs_with_suffix(normalized_category)
        or ""
    )

    logger.info_if_or_debug(f"<<yellow>> end jobs_resolvers: {normalized_category=}, {resolved_label=}", resolved_label)
    return resolved_label


__all__ = [
    "resolve_jobs_main",
]



#!/usr/bin/env python3
"""
Unified classifier for geographic vs non-geographic labels.

This script merges:
- Rich keyword taxonomy from split_non_geography.py
- Arabic/English pattern detection from filter_non_geographic.py
- Taxon detection (biological names)
- Person-role detection (king, queen, president...)
- Cultural/media keywords
- Multi-layer rule-based classification for maximum accuracy

"""

import json
import re
from collections import defaultdict
from pathlib import Path
from typing import Dict, Tuple

base_dir = Path(__file__).parent.parent
jsons_dir = base_dir / "ArWikiCats" / "translations" / "jsons"


# -------------------------------------------------------------
# 1) Robust Keyword Sets (merged + expanded)
# -------------------------------------------------------------
CHECK_AR_ALSO = {
    "park": "بارك",
    "bridge": "بريدج",
}

NON_GEO_KEYWORDS_EN = {
    "education": ["university", "college", "school", "academy", "institute", "faculty", "journal"],
    "medical": ["hospital", "clinic", "medical center"],
    "business": [
        "company",
        "corporation",
        "ltd",
        "inc",
        "limited",
        "enterprise",
        "brand",
        "product",
        "bank",
        "airlines",
        "airways",
        "restaurant",
        "hotel",
    ],
    "Infrastructure": [
        "bridge",
        "tunnel",
        "airport",
        "station",
        "highway",
        "road",
        "railway",
        "canal",
        "pipeline",
        "dam",
        "dike",
        "circuit",
        "center",
        "centre",
        "park",
        "garden",
        "zoo",
    ],
    "religious_cultural_buildings": ["church", "cathedral", "mosque", "temple", "synagogue", "abbey", "monastery"],
    "organizations": [
        "association",
        "organisation",
        "organization",
        "foundation",
        "society",
        "agency",
        "council",
        "union",
        "movement",
    ],
    "military": [
        "army",
        "navy",
        "air force",
        "battalion",
        "regiment",
        "squadron",
    ],
    "Tv": ["film", "tv series", "tv show", "television", "channel", "episode", "series", "movie"],
    "culture_media": [
        "museum",
        "library",
        "gallery",
        "opera",
        "novel",
        "book",
        "movie",
        "season",
        "soundtrack",
        "theater",
        "theatre",
        "poem",
        "play",
        "album",
        "song",
        "single",
        "ballet",
        "musical",
        "magazine",
        "newspaper",
        "script",
        "studios",
        "music",
        "festival",
        "band",
    ],
    "sports": [
        "club",
        "team",
        "fc",
        "sc",
        "league",
        "tournament",
        "stadium",
        "arena",
        "championship",
        "cup",
        "race",
        "grand prix",
        "clubs",
        "f.c.",
        "نادي",
    ],
    "politics_law": [
        "government",
        "ministry",
        "court",
        "constitution",
        "policy",
        "election",
        "presidential",
        "parliament",
        "senate",
        "law",
        "legal",
        "case",
        "presidential election",
        "politics",
        "assembly",
        "treaty",
        "party",
    ],
    "media_technology": [
        "software",
        "protocol",
        "video game",
        "algorithm",
        "programming language",
        "operating system",
        "board game",
    ],
    "biology_scientific": [
        "virus",
        "bacteria",
        "species",
        "genus",
        "family",
        "order",
        "mammal",
        "bird",
        "fish",
        "fungus",
        "plant",
        "animal",
        "insect",
    ],
    "roles_people": [
        "king",
        "queen",
        "prince",
        "emperor",
        "president",
        "minister",
        "lord",
        "sir",
        "judge",
        "politician",
        "artist",
        "actor",
        "actress",
        "singer",
        "writer",
        "author",
        "poet",
        "philosopher",
        "scientist",
        "musician",
        "composer",
        "director",
        "producer",
        "footballer",
        "basketball player",
        "baseball player",
        "coach",
        "businessman",
        "businesswoman",
        "people",
    ],
    "mythology_religion": ["mythology", "goddess", "god", "mythical", "religion", "sect", "liturgy"],
    "historical_societal": [
        # "clan", "empire", "kingdom",
        "tribe",
        "war",
        "battle",
        "front",
    ],
    # "dynasty": [ "dynasty" ],
    "languages": ["language"],
    "awards": ["award", "medal", "prize", "trophy"],
    "institutions_other": ["department", "dialect", "police", "prison"],
    "others": [
        "history of",
        "culture of",
        "economy of",
        "demographics of",
        "transport in",
        "infrastructure of",
        "tourism in",
    ],
}

# -------------------------------------------------------------
# 2) Arabic pattern detection
# -------------------------------------------------------------

NON_GEO_KEYWORDS_AR = [
    "جامعة",
    "كلية",
    "معهد",
    "نادي",
    "شركة",
    "مستشفى",
    "متحف",
    "جمعية",
    "فندق",
    "ملعب",
    "جسر",
    "قناة",
    "محطة",
    "مطار",
]

# -------------------------------------------------------------
# 3) Biological suffixes
# -------------------------------------------------------------

TAXON_SUFFIXES = (
    "aceae",
    "ales",
    "ineae",
    "phyta",
    "phyceae",
    "mycetes",
    "mycota",
    "formes",
    "idae",
    "inae",
    "oidea",
    "morpha",
    "cetes",
    "phycidae",
)


# -------------------------------------------------------------
# Detection Helpers
# -------------------------------------------------------------


def detect_english_keywords(label: str, value: str) -> bool:
    """Return True if English keyword matches exactly or by token."""
    lowered = label.lower()
    for name, keywords in NON_GEO_KEYWORDS_EN.items():
        for keyword in keywords:
            # ----
            ar_word = CHECK_AR_ALSO.get(keyword)
            # ----
            # pattern = rf"\b{re.escape(keyword)}\b"
            pattern = rf"(?<!\w){re.escape(keyword)}(?!\w)"
            # ---
            if not re.search(pattern, lowered) and not re.search(pattern, value):
                continue
            # ---
            if not ar_word:
                return True, name
            # ---
            if ar_word:
                # ar_pattern = rf"\b{re.escape(ar_word)}\b"
                ar_pattern = rf"(?<!\w){re.escape(ar_word)}(?!\w)"

                if re.search(ar_pattern, value):
                    return False, ""
            # ---
            return True, name
    return False, ""


def detect_arabic_keywords(value: str) -> bool:
    """Return True if target Arabic keyword appears."""
    for keyword in NON_GEO_KEYWORDS_AR:
        if keyword in value:
            return True
    return False


def detect_taxon(label: str) -> bool:
    """Detect biological taxon names by suffix."""
    lowered = label.lower()
    return any(lowered.endswith(suffix) for suffix in TAXON_SUFFIXES)


def detect_person_like(label: str) -> bool:
    """Detect if label refers to persons/titles."""
    lowered = label.lower()
    # Heuristic: titles containing commas that denote roles (e.g., "king of", "queen of")
    roles = ("king", "queen", "president", "chancellor", "minister", "lord", "sir", "prince")
    return any(
        re.search(
            # rf"\b{role}\b",
            rf"(?<!\w){role}(?!\w)",
            lowered,
        )
        for role in roles
    )


# -------------------------------------------------------------
# Filtering Logic
# -------------------------------------------------------------


def classify_entries(entries: Dict[str, str]) -> Tuple[Dict[str, str], Dict[str, str]]:
    """Split entries into geographic and non-geographic."""
    geo = {}
    non_geo = {}
    typies = defaultdict(lambda: defaultdict(int))
    for key, value in entries.items():
        # Layer 1: English keyword detection
        isa, name = detect_english_keywords(key, value)
        if isa:
            non_geo[key] = value
            typies[name][key] = value

        # Layer 2: Arabic keyword detection
        elif detect_arabic_keywords(value):
            non_geo[key] = value
            typies["arabic"][key] = value

        # Layer 3: Biological taxon detection
        elif detect_taxon(key):
            non_geo[key] = value
            typies["taxons"][key] = value

        # Layer 4: Person role detection
        elif detect_person_like(key):
            non_geo[key] = value
            typies["persons"][key] = value
        else:
            geo[key] = value

    typies = dict(sorted(typies.items(), key=lambda item: len(item[1]), reverse=True))

    print(" - Detected\n\t| " + "\n\t| ".join([f" {k}: {len(v)}" for k, v in typies.items()]))

    return geo, typies


def filter_file(input_path: Path, geo_out: Path, non_geo_out: Path) -> str:
    """Read → classify → write outputs."""
    data = json.loads(input_path.read_text(encoding="utf-8"))
    geo, non_geo = classify_entries(data)
    non = len(data) - len(geo)
    if non:
        # Write output files
        with open(geo_out, "w", encoding="utf-8") as f:
            json.dump(geo, f, ensure_ascii=False, indent=4, sort_keys=True)

        with open(non_geo_out, "w", encoding="utf-8") as f:
            json.dump(non_geo, f, ensure_ascii=False, indent=4, sort_keys=True)

    return f"Total: {len(data):,} | Geographic: {len(geo):,} | Non-Geographic: {non:,}"


def main() -> None:
    files = [
        # jsons_dir / "geography/P17_2_final_ll.json",
        # jsons_dir / "cities/cities_full.json",
        # jsons_dir / "cities/yy2.json",
        # jsons_dir / "geography/popopo.json",
        jsons_dir
        / "geography/P17_PP.json",
    ]
    status = {}
    for file in files:
        print(f"Processing file: {file}")
        new_path = file.parent.parent / f"{file.parent.name}_new"
        new_path.mkdir(parents=True, exist_ok=True)

        NEW_FILE = new_path / file.name
        NON_GEO_FILE = new_path / f"{file.stem}_non.json"

        stat = filter_file(file, NEW_FILE, NON_GEO_FILE)
        status[file.name] = stat
    # ---
    for fname, stat in status.items():
        print(f"{fname} => {stat}")
    # ---
    print("Processing complete.")


if __name__ == "__main__":
    main()



#!/usr/bin/python3
"""Integration tests for FormatDataV2 with nationality placeholders."""

import pytest

from ArWikiCats.translations_formats import FormatDataV2


@pytest.fixture
def bot() -> FormatDataV2:
    """FormatDataV2 instance configured for nationality-based categories."""
    nationality_data = {
        "egyptian": {
            "male": "مصري",
            "female": "مصرية",
            "males": "مصريون",
            "females": "مصريات",
        },
        "algerian": {
            "male": "جزائري",
            "female": "جزائرية",
            "males": "جزائريون",
            "females": "جزائريات",
        },
        "moroccan": {
            "male": "مغربي",
            "female": "مغربية",
            "males": "مغاربة",
            "females": "مغربيات",
        },
        "yemeni": {
            "male": "يمني",
            "female": "يمنية",
            "males": "يمنيون",
            "females": "يمنيات",
        },
    }

    formatted_data = {
        # Uses {males}
        "{nat_en} writers": "كتاب {males}",
        "{nat_en} poets": "شعراء {males}",
        "{nat_en} people": "أعلام {males}",
        "{nat_en} heroes": "أبطال {males}",
        # Uses {male}
        "{nat_en} descent": "أصل {male}",
        # Uses {females}
        "{nat_en} women activists": "ناشطات {females}",
        "{nat_en} women politicians": "سياسيات {females}",
        "{nat_en} female singers": "مغنيات {females}",
        # Uses {female}
        "{nat_en} gods": "آلهة {female}",
        # Mixed placeholders in the same template
        "{nat_en} males and women": "رجال {males} ونساء {females}",
        # For get_template_ar tests (with/without Category: prefix)
        "{nat_en} philosophers": "فلاسفة {males}",
    }

    return FormatDataV2(
        formatted_data=formatted_data,
        data_list=nationality_data,
        key_placeholder="{nat_en}",
        text_before="the ",
    )


# -----------------------------
# Happy-path tests (all forms)
# -----------------------------

basic_cases = {
    # {males}
    "Algerian writers": "كتاب جزائريون",
    "Yemeni writers": "كتاب يمنيون",
    "Yemeni poets": "شعراء يمنيون",
    # {male}
    "Moroccan descent": "أصل مغربي",
    # {females}
    "Algerian women activists": "ناشطات جزائريات",
    "yemeni women politicians": "سياسيات يمنيات",
    "egyptian female singers": "مغنيات مصريات",
    # {female}
    "egyptian gods": "آلهة مصرية",
    # Extra spaces and mixed case
    "  Moroccan   writers  ": "كتاب مغاربة",
}


@pytest.mark.parametrize("category, expected", basic_cases.items(), ids=basic_cases.keys())
@pytest.mark.fast
def test_search_nationality_basic(bot: FormatDataV2, category: str, expected: str) -> None:
    """Ensure all basic nationality cases resolve correctly."""
    result = bot.search(category)
    assert result == expected


# -----------------------------
# Mixed placeholders
# -----------------------------


@pytest.mark.fast
def test_search_nationality_mixed_placeholders(bot: FormatDataV2) -> None:
    """Template that uses both {males} and {females} in the same label."""
    category = "Yemeni males and women"
    expected = "رجال يمنيون ونساء يمنيات"
    assert bot.search(category) == expected


# -----------------------------
# Negative / edge cases
# -----------------------------


@pytest.mark.fast
def test_search_unknown_nationality_returns_empty(bot: FormatDataV2) -> None:
    """If nationality is not in data_list, search should return an empty string."""
    assert bot.search("Spanish writers") == ""


@pytest.mark.fast
def test_search_missing_template_returns_empty(bot: FormatDataV2) -> None:
    """If template does not exist for a known nationality, search should return empty."""
    # 'Yemeni dancers' has no matching '{nat_en} dancers' template
    assert bot.search("Yemeni dancers") == ""


@pytest.mark.fast
def test_match_key_normalizes_whitespace_and_case(bot: FormatDataV2) -> None:
    """match_key should ignore extra spaces and be case-insensitive."""
    category = "   yemeni   WRITERS  "
    key = bot.match_key(category)
    assert key == "yemeni"


@pytest.mark.fast
def test_match_key_does_not_match_inside_longer_words(bot: FormatDataV2) -> None:
    """
    Ensure regex does not match nationality keys inside larger words.

    'egyptian' should not match inside 'preEgyptian'.
    """
    category = "preEgyptian writers"
    key = bot.match_key(category)
    assert key == ""


# -----------------------------
# Direct tests for helpers
# -----------------------------


@pytest.mark.fast
def test_normalize_category_with_key(bot: FormatDataV2) -> None:
    """normalize_category_with_key should return the key and placeholder-normalized category."""
    category = "Yemeni writers"
    key, normalized = bot.normalize_category_with_key(category)
    assert key == "yemeni"
    assert normalized == "{nat_en} writers"


@pytest.mark.fast
def test_get_template_ar_supports_category_prefix(bot: FormatDataV2) -> None:
    """
    get_template_ar should resolve the same template with or without 'Category:' prefix.
    """
    # Without prefix
    base_template = bot.get_template_ar("{nat_en} philosophers")
    # With 'Category:' prefix; get_template_ar should normalize
    prefixed_template = bot.get_template_ar("Category:{nat_en} philosophers")

    assert base_template == "فلاسفة {males}"
    assert prefixed_template == "فلاسفة {males}"


@pytest.mark.fast
def test_match_key_descent(bot: FormatDataV2) -> None:
    """
    "people of Moroccan-Jewish descent": "أعلام من أصل يهودي مغربي",
    Ensure regex does not match nationality keys inside larger words.

    'egyptian' should not match inside 'preEgyptian'.
    """
    category = "people of Moroccan-Jewish descent"

    key1 = bot.match_key(category)
    key2, normalized = bot.normalize_category_with_key(category)

    assert key2 == key1 == "moroccan", f"Expected 'moroccan', got {key1} and {key2}"


@pytest.mark.fast
def test_normalize_category_descent(bot: FormatDataV2) -> None:
    """
    "people of Moroccan-Jewish descent": "أعلام من أصل يهودي مغربي",
    Ensure regex does not match nationality keys inside larger words.

    'egyptian' should not match inside 'preEgyptian'.
    """
    category = "people of the Moroccan-Jewish descent"

    normalized = bot.normalize_category(category, "moroccan")

    assert normalized == "people of {nat_en}-Jewish descent"



#
import pytest
from load_one_data import dump_diff, dump_diff_text, one_dump_test

from ArWikiCats import resolve_label_ar

data_skip = {
    "January 2021 in Antigua and Barbuda": "أنتيغوا وباربودا في يناير 2021",
    "November 2018 in Antigua and Barbuda": "أنتيغوا وباربودا في نوفمبر 2018",
    "October 2023 in Antigua and Barbuda": "أنتيغوا وباربودا في أكتوبر 2023",
    "March 2018 in Antigua and Barbuda": "أنتيغوا وباربودا في مارس 2018",
    "March 2021 in Antigua and Barbuda": "أنتيغوا وباربودا في مارس 2021",
    "March 2023 in Antigua and Barbuda": "أنتيغوا وباربودا في مارس 2023",
    "Antigua and Barbuda and the Commonwealth of Nations": "x",
    "Antigua and Barbuda articles by importance": "x",
    "Antigua and Barbuda articles by quality": "x",
    "Antigua and Barbuda at the Junior Pan American Games": "x",
    "Antigua and Barbuda aviation law": "x",
    "Antigua and Barbuda beauty pageant winners": "x",
    "Antigua and Barbuda calypsonians": "x",
    "Antigua and Barbuda court system": "x",
    "Antigua and Barbuda cricket people": "x",
    "Antigua and Barbuda dressage riders": "x",
    "Antigua and Barbuda evangelicals": "x",
    "Antigua and Barbuda fiction": "x",
    "Antigua and Barbuda Football Association competitions": "x",
    "Antigua and Barbuda geography-related lists": "x",
    "Antigua and Barbuda judges on the courts of Anguilla": "x",
    "Antigua and Barbuda judges on the courts of Belize": "x",
    "Antigua and Barbuda judges on the courts of Grenada": "x",
    "Antigua and Barbuda judges on the courts of Montserrat": "x",
    "Antigua and Barbuda judges on the courts of Saint Lucia": "x",
    "Antigua and Barbuda knights": "x",
    "Antigua and Barbuda Labour Party politicians": "x",
    "Antigua and Barbuda location map modules": "x",
    "Antigua and Barbuda masters athletes": "x",
    "Antigua and Barbuda modules": "x",
    "Antigua and Barbuda people of Saint Kitts and Nevis descent": "x",
    "Antigua and Barbuda Protestants": "x",
    "Antigua and Barbuda records": "x",
    "Antigua and Barbuda religion-related lists": "x",
    "Antigua and Barbuda Salvationists": "x",
    "Antigua and Barbuda Seventh-day Adventists": "x",
    "Antigua and Barbuda slave owners": "x",
    "Antigua and Barbuda social democrats": "x",
    "Antigua and Barbuda stub templates": "x",
    "Antigua and Barbuda transport-related lists": "x",
    "Antigua and Barbuda user categories": "x",
    "Antigua and Barbuda user templates": "x",
    "Antigua and Barbuda Wikipedians": "x",
    "Antigua and Barbuda–Holy See relations": "x",
    "Apostolic nuncios to Antigua and Barbuda": "x",
    "Australian judges on the courts of Antigua and Barbuda": "x",
    "Baroque architecture in Antigua and Barbuda": "x",
    "Beauty pageants in Antigua and Barbuda": "x",
    "Bilateral sports relations of Antigua and Barbuda": "x",
    "Bird family (Antigua and Barbuda)": "x",
    "British judges on the courts of Antigua and Barbuda": "x",
    "British Virgin Islands expatriates in Antigua and Barbuda": "x",
    "British Virgin Islands judges on the courts of Antigua and Barbuda": "x",
    "Buildings and structures in Saint John Parish, Antigua and Barbuda": "x",
    "By-elections in Antigua and Barbuda": "x",
    "Catholic Church in Antigua and Barbuda": "x",
    "Catholic secondary schools in Antigua and Barbuda": "x",
    "Constitution of Antigua and Barbuda": "x",
    "Country data templates of Antigua and Barbuda": "x",
    "Cricket grounds in Antigua and Barbuda": "x",
    "Dominica expatriate sportspeople in Antigua and Barbuda": "x",
    "Dominica expatriates in Antigua and Barbuda": "x",
    "Dominica judges on the courts of Antigua and Barbuda": "x",
    "Dominica people of Antigua and Barbuda descent": "x",
    "Dominican Republic expatriate sportspeople in Antigua and Barbuda": "x",
    "Education, sports and creative industries ministers of Antigua and Barbuda": "x",
    "Emergency services in Antigua and Barbuda": "x",
    "Endemic birds of Antigua and Barbuda": "x",
    "Endemic fauna of Antigua and Barbuda": "x",
    "Expatriate judges on the courts of Antigua and Barbuda": "x",
    "Federalism in Antigua and Barbuda": "x",
    "Folk festivals in Antigua and Barbuda": "x",
    "Ghanaian judges on the courts of Antigua and Barbuda": "x",
    "Girls' schools in Antigua and Barbuda": "x",
    "Guyanese judges on the courts of Antigua and Barbuda": "x",
    "High commissioners of Antigua and Barbuda": "x",
    "High commissioners of Antigua and Barbuda to Canada": "x",
    "High commissioners of Antigua and Barbuda to Saint Kitts and Nevis": "x",
    "High commissioners of Antigua and Barbuda to the United Kingdom": "x",
    "High commissioners of Australia to Antigua and Barbuda": "x",
    "High commissioners of Canada to Antigua and Barbuda": "x",
    "High commissioners of India to Antigua and Barbuda": "x",
    "High commissioners of South Africa to Antigua and Barbuda": "x",
    "High commissioners of the United Kingdom to Antigua and Barbuda": "x",
    "High commissioners to Antigua and Barbuda": "x",
    "High schools and secondary schools in Antigua and Barbuda": "x",
    "History of sport in Antigua and Barbuda": "x",
    "Hurricanes in Antigua and Barbuda": "x",
    "Important Bird Areas of Antigua and Barbuda": "x",
    "Jamaican judges on the courts of Antigua and Barbuda": "x",
    "John Hughes, Antigua and Barbuda": "x",
    "Judicial Committee of the Privy Council cases on appeal from Antigua and Barbuda": "x",
    "Major divisions of Antigua and Barbuda": "x",
    "Members of the 14th legislature of Antigua and Barbuda": "x",
    "Members of the 15th legislature of Antigua and Barbuda": "x",
    "Members of the 16th legislature of Antigua and Barbuda": "x",
    "Members of the House of Representatives (Antigua and Barbuda)": "x",
    "Merchant ships of Antigua and Barbuda": "x",
    "Micronations in Antigua and Barbuda": "x",
    "Monarchy of Antigua and Barbuda": "x",
    "National Cultural Heritage of Antigua and Barbuda": "x",
    "National Security Council (Antigua and Barbuda)": "x",
    "Olympic sailors for Antigua and Barbuda": "x",
    "Parades in Antigua and Barbuda": "x",
    "Parliaments of Antigua and Barbuda": "x",
    "People from Saint George, Antigua and Barbuda": "x",
    "People from Saint John, Antigua and Barbuda": "x",
    "People from Saint Mary, Antigua and Barbuda": "x",
    "People from Saint Paul, Antigua and Barbuda": "x",
    "People from Saint Peter, Antigua and Barbuda": "x",
    "People from Saint Philip, Antigua and Barbuda": "x",
    "Permanent representatives of Antigua and Barbuda to the World Trade Organization": "x",
    "Places in Saint John Parish, Antigua and Barbuda": "x",
    "Private islands of Antigua and Barbuda": "x",
    "Ramsar sites in Antigua and Barbuda": "x",
    "Recipients of the Order of the Nation (Antigua and Barbuda)": "x",
    "Recipients of the Order of the National Hero (Antigua and Barbuda)": "x",
    "Republicanism in Antigua and Barbuda": "x",
    "Saint George, Antigua and Barbuda": "x",
    "Saint John, Antigua and Barbuda": "x",
    "Saint Kitts and Nevis expatriates in Antigua and Barbuda": "x",
    "Saint Kitts and Nevis judges on the courts of Antigua and Barbuda": "x",
    "Saint Kitts and Nevis people of Antigua and Barbuda descent": "x",
    "Saint Lucian expatriates in Antigua and Barbuda": "x",
    "Saint Lucian judges on the courts of Antigua and Barbuda": "x",
    "Saint Lucian people of Antigua and Barbuda descent": "x",
    "Saint Mary, Antigua and Barbuda": "x",
    "Saint Paul, Antigua and Barbuda": "x",
    "Saint Peter, Antigua and Barbuda": "x",
    "Saint Philip, Antigua and Barbuda": "x",
    "Saint Vincent and the Grenadines expatriate sportspeople in Antigua and Barbuda": "x",
    "Saint Vincent and the Grenadines expatriates in Antigua and Barbuda": "x",
    "Saint Vincent and the Grenadines judges on the courts of Antigua and Barbuda": "x",
    "Scouting and Guiding in Antigua and Barbuda": "x",
    "Serbia and Montenegro expatriate sportspeople in Antigua and Barbuda": "x",
    "Socialism in Antigua and Barbuda": "x",
    "Speakers of the House of Representatives (Antigua and Barbuda)": "x",
    "United States Virgin Islands people of Antigua and Barbuda descent": "x",
    "Women ambassadors of Antigua and Barbuda": "x",
    "World Athletics Championships athletes for Antigua and Barbuda": "x",
}

data_0 = {
    "Antigua and Barbuda men athletes": "لاعبو قوى أنتيغويون وبربوديون",
    "Antigua and Barbuda men centenarians": "مئويون أنتيغويون وبربوديون",
    "Antigua and Barbuda men high jumpers": "متسابقو قفز عالي أنتيغويون وبربوديون",
    "Antigua and Barbuda men hurdlers": "لاعبو قفز الحواجز أنتيغويون وبربوديون",
    "Antigua and Barbuda men long jumpers": "لاعبو قفز طويل أنتيغويون وبربوديون",
    "Antigua and Barbuda men middle-distance runners": "عداؤو مسافات متوسطة أنتيغويون وبربوديون",
    "Antigua and Barbuda men sprinters": "عداؤون سريعون أنتيغويون وبربوديون",
    "Antigua and Barbuda men triple jumpers": "لاعبو وثب ثلاثي أنتيغويون وبربوديون",
    "Antigua and Barbuda men": "رجال أنتيغويون وبربوديون",
    "Antigua and Barbuda men's basketball players": "لاعبو كرة سلة أنتيغويون وبربوديون",
    "Antigua and Barbuda male actors": "ممثلون ذكور أنتيغويون وبربوديون",
    "Antigua and Barbuda male boxers": "ملاكمون ذكور أنتيغويون وبربوديون",
    "Antigua and Barbuda male canoeists": "متسابقو قوارب الكانوي ذكور أنتيغويون وبربوديون",
    "Antigua and Barbuda male cyclists": "دراجون ذكور أنتيغويون وبربوديون",
    "Antigua and Barbuda male freestyle swimmers": "سباحو تزلج حر ذكور أنتيغويون وبربوديون",
    "Antigua and Barbuda male sailors (sport)": "بحارة رياضيون ذكور أنتيغويون وبربوديون",
    "Antigua and Barbuda male swimmers": "سباحون ذكور أنتيغويون وبربوديون",
    "Antigua and Barbuda male tennis players": "لاعبو كرة مضرب ذكور أنتيغويون وبربوديون",
    "Antigua and Barbuda men's footballers": "لاعبو كرة قدم أنتيغويون وبربوديون",
    "Men's footballers in Antigua and Barbuda by club": "لاعبو كرة قدم في أنتيغوا وباربودا حسب النادي",
    "Antigua and Barbuda expatriate footballers": "لاعبو كرة قدم أنتيغويون وبربوديون مغتربون",
    "Antigua and Barbuda expatriate men's footballers": "لاعبو كرة قدم أنتيغويون وبربوديون مغتربون",
}

data_1 = {
    "21st-century Antigua and Barbuda politicians": "سياسيون أنتيغويون وبربوديون في القرن 21",
    "21st-century Antigua and Barbuda people": "أنتيغويون وبربوديون في القرن 21",
    "New Zealand emigrants to Antigua and Barbuda": "نيوزيلنديون مهاجرون إلى أنتيغوا وباربودا",
    "Paralympic competitors for Antigua and Barbuda": "منافسون بارالمبيون من أنتيغوا وباربودا",
    "Antigua and Barbuda people of New Zealand descent": "أنتيغويون وبربوديون من أصل نيوزيلندي",
    "Antigua and Barbuda sportsmen": "رياضيون رجال أنتيغويون وبربوديون",
    "21st-century Antigua and Barbuda sportsmen": "رياضيون رجال أنتيغويون وبربوديون في القرن 21",
    "Antigua and Barbuda clergy": "رجال دين أنتيغويون وبربوديون",
    "Men in Antigua and Barbuda": "رجال في أنتيغوا وباربودا",
    "1930s establishments in Antigua and Barbuda": "تأسيسات عقد 1930 في أنتيغوا وباربودا",
    "1930s in Antigua and Barbuda": "أنتيغوا وباربودا في عقد 1930",
    "1939 establishments in Antigua and Barbuda": "تأسيسات سنة 1939 في أنتيغوا وباربودا",
    "1939 in Antigua and Barbuda": "أنتيغوا وباربودا في 1939",
    "1940s establishments in Antigua and Barbuda": "تأسيسات عقد 1940 في أنتيغوا وباربودا",
    "1940s in Antigua and Barbuda": "أنتيغوا وباربودا في عقد 1940",
    "1946 in Antigua and Barbuda": "أنتيغوا وباربودا في 1946",
    "1947 establishments in Antigua and Barbuda": "تأسيسات سنة 1947 في أنتيغوا وباربودا",
    "1947 in Antigua and Barbuda": "أنتيغوا وباربودا في 1947",
    "1950s in Antigua and Barbuda": "أنتيغوا وباربودا في عقد 1950",
    "1951 in Antigua and Barbuda": "أنتيغوا وباربودا في 1951",
    "1956 in Antigua and Barbuda": "أنتيغوا وباربودا في 1956",
    "1960 establishments in Antigua and Barbuda": "تأسيسات سنة 1960 في أنتيغوا وباربودا",
    "1960 in Antigua and Barbuda": "أنتيغوا وباربودا في 1960",
    "1960s disestablishments in Antigua and Barbuda": "انحلالات عقد 1960 في أنتيغوا وباربودا",
    "1965 establishments in Antigua and Barbuda": "تأسيسات سنة 1965 في أنتيغوا وباربودا",
    "1965 in Antigua and Barbuda": "أنتيغوا وباربودا في 1965",
    "1966 establishments in Antigua and Barbuda": "تأسيسات سنة 1966 في أنتيغوا وباربودا",
    "1966 in Antigua and Barbuda": "أنتيغوا وباربودا في 1966",
    "1967 disestablishments in Antigua and Barbuda": "انحلالات سنة 1967 في أنتيغوا وباربودا",
    "1967 in Antigua and Barbuda": "أنتيغوا وباربودا في 1967",
    "1968 in Antigua and Barbuda": "أنتيغوا وباربودا في 1968",
    "1969 establishments in Antigua and Barbuda": "تأسيسات سنة 1969 في أنتيغوا وباربودا",
    "1969 in Antigua and Barbuda": "أنتيغوا وباربودا في 1969",
    "1971 establishments in Antigua and Barbuda": "تأسيسات سنة 1971 في أنتيغوا وباربودا",
    "1971 in Antigua and Barbuda": "أنتيغوا وباربودا في 1971",
    "1978 in Antigua and Barbuda": "أنتيغوا وباربودا في 1978",
    "1979 establishments in Antigua and Barbuda": "تأسيسات سنة 1979 في أنتيغوا وباربودا",
    "1979 in Antigua and Barbuda": "أنتيغوا وباربودا في 1979",
    "1980 establishments in Antigua and Barbuda": "تأسيسات سنة 1980 في أنتيغوا وباربودا",
    "1980 in Antigua and Barbuda": "أنتيغوا وباربودا في 1980",
    "1980s disestablishments in Antigua and Barbuda": "انحلالات عقد 1980 في أنتيغوا وباربودا",
    "1980s in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في عقد 1980",
    "1981 disestablishments in Antigua and Barbuda": "انحلالات سنة 1981 في أنتيغوا وباربودا",
    "1982 establishments in Antigua and Barbuda": "تأسيسات سنة 1982 في أنتيغوا وباربودا",
    "1982 in Antigua and Barbuda": "أنتيغوا وباربودا في 1982",
    "1983 in Antigua and Barbuda": "أنتيغوا وباربودا في 1983",
    "1983 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 1983",
    "1984 in Antigua and Barbuda": "أنتيغوا وباربودا في 1984",
    "1986 disestablishments in Antigua and Barbuda": "انحلالات سنة 1986 في أنتيغوا وباربودا",
    "1986 establishments in Antigua and Barbuda": "تأسيسات سنة 1986 في أنتيغوا وباربودا",
    "1986 in Antigua and Barbuda": "أنتيغوا وباربودا في 1986",
    "1987 establishments in Antigua and Barbuda": "تأسيسات سنة 1987 في أنتيغوا وباربودا",
    "1987 in Antigua and Barbuda": "أنتيغوا وباربودا في 1987",
    "1988 establishments in Antigua and Barbuda": "تأسيسات سنة 1988 في أنتيغوا وباربودا",
    "1988 in Antigua and Barbuda": "أنتيغوا وباربودا في 1988",
    "1989 in Antigua and Barbuda": "أنتيغوا وباربودا في 1989",
    "1990s disestablishments in Antigua and Barbuda": "انحلالات عقد 1990 في أنتيغوا وباربودا",
    "1990s in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في عقد 1990",
    "1991 establishments in Antigua and Barbuda": "تأسيسات سنة 1991 في أنتيغوا وباربودا",
    "1991 in Antigua and Barbuda": "أنتيغوا وباربودا في 1991",
    "1992 disestablishments in Antigua and Barbuda": "انحلالات سنة 1992 في أنتيغوا وباربودا",
    "1992 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 1992",
    "1994 in Antigua and Barbuda": "أنتيغوا وباربودا في 1994",
    "1995 establishments in Antigua and Barbuda": "تأسيسات سنة 1995 في أنتيغوا وباربودا",
    "1995 in Antigua and Barbuda": "أنتيغوا وباربودا في 1995",
    "1995 in Antigua and Barbuda law": "قانون أنتيغوي وبربودي في 1995",
    "1996 in Antigua and Barbuda": "أنتيغوا وباربودا في 1996",
    "1996 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 1996",
    "1997 in Antigua and Barbuda": "أنتيغوا وباربودا في 1997",
    "1997 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 1997",
    "1998 establishments in Antigua and Barbuda": "تأسيسات سنة 1998 في أنتيغوا وباربودا",
    "1998 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 1998",
    "1999 establishments in Antigua and Barbuda": "تأسيسات سنة 1999 في أنتيغوا وباربودا",
    "1999 in Antigua and Barbuda": "أنتيغوا وباربودا في 1999",
    "1999 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 1999",
    "2000 in Antigua and Barbuda": "أنتيغوا وباربودا في 2000",
    "2000 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2000",
    "2000s disestablishments in Antigua and Barbuda": "انحلالات عقد 2000 في أنتيغوا وباربودا",
    "2000s in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في عقد 2000",
    "2001 establishments in Antigua and Barbuda": "تأسيسات سنة 2001 في أنتيغوا وباربودا",
    "2001 in Antigua and Barbuda": "أنتيغوا وباربودا في 2001",
    "2002 in Antigua and Barbuda": "أنتيغوا وباربودا في 2002",
    "2002 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2002",
    "2003 in Antigua and Barbuda law": "قانون أنتيغوي وبربودي في 2003",
    "2004 establishments in Antigua and Barbuda": "تأسيسات سنة 2004 في أنتيغوا وباربودا",
    "2004 in Antigua and Barbuda": "أنتيغوا وباربودا في 2004",
    "2004 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2004",
    "2005 in Antigua and Barbuda": "أنتيغوا وباربودا في 2005",
    "2005 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2005",
    "2006 in Antigua and Barbuda law": "قانون أنتيغوي وبربودي في 2006",
    "2006 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2006",
    "2007 in Antigua and Barbuda": "أنتيغوا وباربودا في 2007",
    "2007 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2007",
    "2008 in Antigua and Barbuda": "أنتيغوا وباربودا في 2008",
    "2008 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2008",
    "2009 disestablishments in Antigua and Barbuda": "انحلالات سنة 2009 في أنتيغوا وباربودا",
    "2009 in Antigua and Barbuda": "أنتيغوا وباربودا في 2009",
    "2009 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2009",
    "2010 in Antigua and Barbuda": "أنتيغوا وباربودا في 2010",
    "2010 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2010",
    "2010s disestablishments in Antigua and Barbuda": "انحلالات عقد 2010 في أنتيغوا وباربودا",
    "2010s establishments in Antigua and Barbuda": "تأسيسات عقد 2010 في أنتيغوا وباربودا",
    "2010s in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في عقد 2010",
    "2011 in Antigua and Barbuda": "أنتيغوا وباربودا في 2011",
    "2011 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2011",
    "2012 in Antigua and Barbuda": "أنتيغوا وباربودا في 2012",
    "2012 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2012",
    "2013 establishments in Antigua and Barbuda": "تأسيسات سنة 2013 في أنتيغوا وباربودا",
    "2013 in Antigua and Barbuda": "أنتيغوا وباربودا في 2013",
    "2013 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2013",
    "2014 in Antigua and Barbuda": "أنتيغوا وباربودا في 2014",
    "2014 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2014",
    "2015 disestablishments in Antigua and Barbuda": "انحلالات سنة 2015 في أنتيغوا وباربودا",
    "2015 in Antigua and Barbuda": "أنتيغوا وباربودا في 2015",
    "2015 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2015",
    "2016 in Antigua and Barbuda": "أنتيغوا وباربودا في 2016",
    "2016 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2016",
    "2017 in Antigua and Barbuda": "أنتيغوا وباربودا في 2017",
    "2017 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2017",
    "2018 in Antigua and Barbuda": "أنتيغوا وباربودا في 2018",
    "2018 in Antigua and Barbuda by month": "أنتيغوا وباربودا في 2018 حسب الشهر",
    "2018 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2018",
    "2019 in Antigua and Barbuda": "أنتيغوا وباربودا في 2019",
    "2019 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2019",
    "2020 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2020",
    "2020s in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في عقد 2020",
    "2021 in Antigua and Barbuda by month": "أنتيغوا وباربودا في 2021 حسب الشهر",
    "2021 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2021",
    "2022 in Antigua and Barbuda": "أنتيغوا وباربودا في 2022",
    "2022 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2022",
    "2023 in Antigua and Barbuda": "أنتيغوا وباربودا في 2023",
    "2023 in Antigua and Barbuda by month": "أنتيغوا وباربودا في 2023 حسب الشهر",
    "2023 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2023",
    "2024 in Antigua and Barbuda": "أنتيغوا وباربودا في 2024",
    "2024 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2024",
    "2025 in Antigua and Barbuda": "أنتيغوا وباربودا في 2025",
    "2025 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2025",
    "2026 in Antigua and Barbuda": "أنتيغوا وباربودا في 2026",
    "20th-century disestablishments in Antigua and Barbuda": "انحلالات القرن 20 في أنتيغوا وباربودا",
    "21st-century disestablishments in Antigua and Barbuda": "انحلالات القرن 21 في أنتيغوا وباربودا",
    "2nd-millennium disestablishments in Antigua and Barbuda": "انحلالات الألفية 2 في أنتيغوا وباربودا",
    "3rd-millennium disestablishments in Antigua and Barbuda": "انحلالات الألفية 3 في أنتيغوا وباربودا",
    "Airlines of Antigua and Barbuda": "شركات طيران في أنتيغوا وباربودا",
    "Ambassadors of Antigua and Barbuda to Estonia": "سفراء أنتيغوا وباربودا لدى إستونيا",
    "Ambassadors of Antigua and Barbuda to France": "سفراء أنتيغوا وباربودا لدى فرنسا",
    "Ambassadors of Antigua and Barbuda to Germany": "سفراء أنتيغوا وباربودا لدى ألمانيا",
    "Ambassadors of Antigua and Barbuda to Israel": "سفراء أنتيغوا وباربودا لدى إسرائيل",
    "Ambassadors of Antigua and Barbuda to Italy": "سفراء أنتيغوا وباربودا لدى إيطاليا",
    "Ambassadors of Antigua and Barbuda to Russia": "سفراء أنتيغوا وباربودا لدى روسيا",
    "Ambassadors of Antigua and Barbuda to Spain": "سفراء أنتيغوا وباربودا لدى إسبانيا",
    "Ambassadors of Antigua and Barbuda to the United States": "سفراء أنتيغوا وباربودا لدى الولايات المتحدة",
    "Ambassadors of China to Antigua and Barbuda": "سفراء الصين لدى أنتيغوا وباربودا",
    "Ambassadors of Israel to Antigua and Barbuda": "سفراء إسرائيل لدى أنتيغوا وباربودا",
    "Ambassadors of Japan to Antigua and Barbuda": "سفراء اليابان لدى أنتيغوا وباربودا",
    "Ambassadors of Poland to Antigua and Barbuda": "سفراء بولندا لدى أنتيغوا وباربودا",
    "American people of Antigua and Barbuda descent": "أمريكيون من أصل أنتيغوي وبربودي",
    "Amphibians of Antigua and Barbuda": "برمائيات أنتيغوا وباربودا",
    "Anguillan emigrants to Antigua and Barbuda": "أنغويلانيون مهاجرون إلى أنتيغوا وباربودا",
    "Antigua and Barbuda activists": "ناشطون أنتيغويون وبربوديون",
    "Antigua and Barbuda actors": "ممثلون أنتيغويون وبربوديون",
    "Antigua and Barbuda amputees": "أنتيغويون وبربوديون مبتورو أحد الأطراف",
    "Antigua and Barbuda artists": "فنانون أنتيغويون وبربوديون",
    "Antigua and Barbuda at the Pan American Games": "أنتيغوا وباربودا في دورة الألعاب الأمريكية",
    "Antigua and Barbuda at the Paralympics": "أنتيغوا وباربودا في الألعاب البارالمبية",
    "Antigua and Barbuda at the World Athletics Championships": "أنتيغوا وباربودا في بطولة العالم لألعاب القوى",
    "Antigua and Barbuda at the Youth Olympics": "أنتيغوا وباربودا في الألعاب الأولمبية الشبابية",
    "Antigua and Barbuda athletes": "لاعبو قوى أنتيغويون وبربوديون",
    "Antigua and Barbuda awards": "جوائز أنتيغوية وبربودية",
    "Antigua and Barbuda bankers": "مصرفيون أنتيغويون وبربوديون",
    "Antigua and Barbuda basketball players": "لاعبو كرة سلة أنتيغويون وبربوديون",
    "Antigua and Barbuda bishops": "أساقفة أنتيغويون وبربوديون",
    "Antigua and Barbuda boxers": "ملاكمون أنتيغويون وبربوديون",
    "Antigua and Barbuda businesspeople": "شخصيات أعمال أنتيغوية وبربودية",
    "Antigua and Barbuda businesswomen": "سيدات أعمال أنتيغويات وبربوديات",
    "Antigua and Barbuda canoeists": "متسابقو قوارب الكانوي أنتيغويون وبربوديون",
    "Antigua and Barbuda centenarians": "مئويون أنتيغويون وبربوديون",
    "Antigua and Barbuda Christians": "أنتيغويون وبربوديون مسيحيون",
    "Antigua and Barbuda communications-related lists": "قوائم متعلقة بالاتصالات الأنتيغوية والبربودية",
    "Antigua and Barbuda competitors by sports event": "منافسون أنتيغويون وبربوديون حسب الحدث الرياضي",
    "Antigua and Barbuda cricket coaches": "مدربو كريكت أنتيغويون وبربوديون",
    "Antigua and Barbuda criminals": "مجرمون أنتيغويون وبربوديون",
    "Antigua and Barbuda cuisine": "مطبخ أنتيغوي وبربودي",
    "Antigua and Barbuda cyclists": "دراجون أنتيغويون وبربوديون",
    "Antigua and Barbuda diaspora": "شتات أنتيغوي وبربودي",
    "Antigua and Barbuda diplomacy-related lists": "قوائم متعلقة بالدبلوماسية الأنتيغوية والبربودية",
    "Antigua and Barbuda diplomats": "دبلوماسيون أنتيغويون وبربوديون",
    "Antigua and Barbuda dramatists and playwrights": "كتاب دراما ومسرح أنتيغويون وبربوديون",
    "Antigua and Barbuda drug traffickers": "تجار مخدرات أنتيغويون وبربوديون",
    "Antigua and Barbuda economists": "اقتصاديون أنتيغويون وبربوديون",
    "Antigua and Barbuda educators": "معلمون أنتيغويون وبربوديون",
    "Antigua and Barbuda emigrants": "أنتيغويون وبربوديون مهاجرون",
    "Antigua and Barbuda emigrants to Bermuda": "أنتيغويون وبربوديون مهاجرون إلى برمودا",
    "Antigua and Barbuda emigrants to Canada": "أنتيغويون وبربوديون مهاجرون إلى كندا",
    "Antigua and Barbuda emigrants to England": "أنتيغويون وبربوديون مهاجرون إلى إنجلترا",
    "Antigua and Barbuda emigrants to Saint Kitts and Nevis": "أنتيغويون وبربوديون مهاجرون إلى سانت كيتس ونيفيس",
    "Antigua and Barbuda emigrants to the United Kingdom": "أنتيغويون وبربوديون مهاجرون إلى المملكة المتحدة",
    "Antigua and Barbuda emigrants to the United States": "أنتيغويون وبربوديون مهاجرون إلى الولايات المتحدة",
    "Antigua and Barbuda emigrants to the United States Virgin Islands": "أنتيغويون وبربوديون مهاجرون إلى جزر العذراء الأمريكية",
    "Antigua and Barbuda entertainers": "فنانون ترفيهيون أنتيغويون وبربوديون",
    "Antigua and Barbuda equestrians": "فرسان خيول أنتيغويون وبربوديون",
    "Antigua and Barbuda expatriate basketball people": "أعلام كرة سلة أنتيغويون وبربوديون مغتربون",
    "Antigua and Barbuda expatriate basketball people in France": "أعلام كرة سلة أنتيغويون وبربوديون مغتربون في فرنسا",
    "Antigua and Barbuda expatriate basketball people in Germany": "أعلام كرة سلة أنتيغويون وبربوديون مغتربون في ألمانيا",
    "Antigua and Barbuda expatriate basketball people in Greece": "أعلام كرة سلة أنتيغويون وبربوديون مغتربون في اليونان",
    "Antigua and Barbuda expatriate basketball people in Poland": "أعلام كرة سلة أنتيغويون وبربوديون مغتربون في بولندا",
    "Antigua and Barbuda expatriate basketball people in Puerto Rico": "أعلام كرة سلة أنتيغويون وبربوديون مغتربون في بورتوريكو",
    "Antigua and Barbuda expatriate judges": "قضاة أنتيغويون وبربوديون مغتربون",
    "Antigua and Barbuda expatriate sportspeople": "رياضيون أنتيغويون وبربوديون مغتربون",
    "Antigua and Barbuda expatriate sportspeople by country of residence": "رياضيون أنتيغويون وبربوديون مغتربون حسب بلد الإقامة",
    "Antigua and Barbuda expatriate sportspeople in Cambodia": "رياضيون أنتيغويون وبربوديون مغتربون في كمبوديا",
    "Antigua and Barbuda expatriate sportspeople in Canada": "رياضيون أنتيغويون وبربوديون مغتربون في كندا",
    "Antigua and Barbuda expatriate sportspeople in England": "رياضيون أنتيغويون وبربوديون مغتربون في إنجلترا",
    "Antigua and Barbuda expatriate sportspeople in Finland": "رياضيون أنتيغويون وبربوديون مغتربون في فنلندا",
    "Antigua and Barbuda expatriate sportspeople in France": "رياضيون أنتيغويون وبربوديون مغتربون في فرنسا",
    "Antigua and Barbuda expatriate sportspeople in Germany": "رياضيون أنتيغويون وبربوديون مغتربون في ألمانيا",
    "Antigua and Barbuda expatriate sportspeople in Greece": "رياضيون أنتيغويون وبربوديون مغتربون في اليونان",
    "Antigua and Barbuda expatriate sportspeople in insular areas of the United States": "رياضيون أنتيغويون وبربوديون مغتربون في المناطق المعزولة في الولايات المتحدة",
    "Antigua and Barbuda expatriate sportspeople in Jamaica": "رياضيون أنتيغويون وبربوديون مغتربون في جامايكا",
    "Antigua and Barbuda expatriate sportspeople in Kenya": "رياضيون أنتيغويون وبربوديون مغتربون في كينيا",
    "Antigua and Barbuda expatriate sportspeople in Poland": "رياضيون أنتيغويون وبربوديون مغتربون في بولندا",
    "Antigua and Barbuda expatriate sportspeople in Puerto Rico": "رياضيون أنتيغويون وبربوديون مغتربون في بورتوريكو",
    "Antigua and Barbuda expatriate sportspeople in Slovenia": "رياضيون أنتيغويون وبربوديون مغتربون في سلوفينيا",
    "Antigua and Barbuda expatriate sportspeople in South Africa": "رياضيون أنتيغويون وبربوديون مغتربون في جنوب إفريقيا",
    "Antigua and Barbuda expatriate sportspeople in Thailand": "رياضيون أنتيغويون وبربوديون مغتربون في تايلاند",
    "Antigua and Barbuda expatriate sportspeople in the United Kingdom": "رياضيون أنتيغويون وبربوديون مغتربون في المملكة المتحدة",
    "Antigua and Barbuda expatriate sportspeople in the United States": "رياضيون أنتيغويون وبربوديون مغتربون في الولايات المتحدة",
    "Antigua and Barbuda expatriate sportspeople in Trinidad and Tobago": "رياضيون أنتيغويون وبربوديون مغتربون في ترينيداد وتوباغو",
    "Antigua and Barbuda expatriate sportspeople in Wales": "رياضيون أنتيغويون وبربوديون مغتربون في ويلز",
    "Antigua and Barbuda expatriates": "أنتيغويون وبربوديون مغتربون",
    "Antigua and Barbuda expatriates in Anguilla": "أنتيغويون وبربوديون مغتربون في أنغويلا",
    "Antigua and Barbuda expatriates in Belize": "أنتيغويون وبربوديون مغتربون في بليز",
    "Antigua and Barbuda expatriates in Canada": "أنتيغويون وبربوديون مغتربون في كندا",
    "Antigua and Barbuda expatriates in England": "أنتيغويون وبربوديون مغتربون في إنجلترا",
    "Antigua and Barbuda expatriates in Finland": "أنتيغويون وبربوديون مغتربون في فنلندا",
    "Antigua and Barbuda expatriates in France": "أنتيغويون وبربوديون مغتربون في فرنسا",
    "Antigua and Barbuda expatriates in Germany": "أنتيغويون وبربوديون مغتربون في ألمانيا",
    "Antigua and Barbuda expatriates in Greece": "أنتيغويون وبربوديون مغتربون في اليونان",
    "Antigua and Barbuda expatriates in Grenada": "أنتيغويون وبربوديون مغتربون في غرينادا",
    "Antigua and Barbuda expatriates in insular areas of the United States": "أنتيغويون وبربوديون مغتربون في المناطق المعزولة في الولايات المتحدة",
    "Antigua and Barbuda expatriates in Jamaica": "أنتيغويون وبربوديون مغتربون في جامايكا",
    "Antigua and Barbuda expatriates in Kenya": "أنتيغويون وبربوديون مغتربون في كينيا",
    "Antigua and Barbuda expatriates in Montserrat": "أنتيغويون وبربوديون مغتربون في مونتسرات",
    "Antigua and Barbuda expatriates in Poland": "أنتيغويون وبربوديون مغتربون في بولندا",
    "Antigua and Barbuda expatriates in Puerto Rico": "أنتيغويون وبربوديون مغتربون في بورتوريكو",
    "Antigua and Barbuda expatriates in Saint Lucia": "أنتيغويون وبربوديون مغتربون في سانت لوسيا",
    "Antigua and Barbuda expatriates in South Africa": "أنتيغويون وبربوديون مغتربون في جنوب إفريقيا",
    "Antigua and Barbuda expatriates in the United Kingdom": "أنتيغويون وبربوديون مغتربون في المملكة المتحدة",
    "Antigua and Barbuda expatriates in the United States": "أنتيغويون وبربوديون مغتربون في الولايات المتحدة",
    "Antigua and Barbuda expatriates in Trinidad and Tobago": "أنتيغويون وبربوديون مغتربون في ترينيداد وتوباغو",
    "Antigua and Barbuda expatriates in Wales": "أنتيغويون وبربوديون مغتربون في ويلز",
    "Antigua and Barbuda families": "عائلات أنتيغوية وبربودية",
    "Antigua and Barbuda female canoeists": "متسابقات قوارب الكانوي أنتيغويات وبربوديات",
    "Antigua and Barbuda female cyclists": "دراجات أنتيغويات وبربوديات",
    "Antigua and Barbuda female equestrians": "فارسات خيول أنتيغويات وبربوديات",
    "Antigua and Barbuda female freestyle swimmers": "سباحات تزلج حر أنتيغويات وبربوديات",
    "Antigua and Barbuda female sailors (sport)": "بحارات رياضيات أنتيغويات وبربوديات",
    "Antigua and Barbuda female swimmers": "سباحات أنتيغويات وبربوديات",
    "Antigua and Barbuda filmmakers": "صانعو أفلام أنتيغويون وبربوديون",
    "Antigua and Barbuda films": "أفلام أنتيغوية وبربودية",
    "Antigua and Barbuda Football Association": "الرابطة الأنتيغوية والبربودية لكرة القدم",
    "Antigua and Barbuda football club seasons": "مواسم أندية كرة قدم أنتيغوية وبربودية",
    "Antigua and Barbuda football logos": "شعارات كرة القدم الأنتيغوية والبربودية",
    "Antigua and Barbuda football managers": "مدربو كرة قدم أنتيغويون وبربوديون",
    "Antigua and Barbuda freestyle swimmers": "سباحو تزلج حر أنتيغويون وبربوديون",
    "Antigua and Barbuda high jumpers": "متسابقو قفز عالي أنتيغويون وبربوديون",
    "Antigua and Barbuda hurdlers": "لاعبو قفز الحواجز أنتيغويون وبربوديون",
    "Antigua and Barbuda illustrators": "رسامون توضيحيون أنتيغويون وبربوديون",
    "Antigua and Barbuda in World War II": "أنتيغوا وباربودا في الحرب العالمية الثانية",
    "Antigua and Barbuda Jews": "أنتيغويون وبربوديون يهود",
    "Antigua and Barbuda judges": "قضاة أنتيغويون وبربوديون",
    "Antigua and Barbuda judges of international courts and tribunals": "قضاة أنتيغويون وبربوديون في محاكم وهيئات قضائية دولية",
    "Antigua and Barbuda jurists": "حقوقيون أنتيغويون وبربوديون",
    "Antigua and Barbuda law by year": "قانون أنتيغوي وبربودي حسب السنة",
    "Antigua and Barbuda lawyers": "محامون أنتيغويون وبربوديون",
    "Antigua and Barbuda literature": "أدب أنتيغوي وبربودي",
    "Antigua and Barbuda long jumpers": "لاعبو قفز طويل أنتيغويون وبربوديون",
    "Antigua and Barbuda Methodists": "ميثوديون أنتيغويون وبربوديون",
    "Antigua and Barbuda middle-distance runners": "عداؤو مسافات متوسطة أنتيغويون وبربوديون",
    "Antigua and Barbuda murder victims": "ضحايا قتل أنتيغويون وبربوديون",
    "Antigua and Barbuda musical groups": "فرق موسيقية أنتيغوية وبربودية",
    "Antigua and Barbuda musicians": "موسيقيون أنتيغويون وبربوديون",
    "Antigua and Barbuda navigational boxes": "صناديق تصفح أنتيغوا وباربودا",
    "Antigua and Barbuda novels": "روايات أنتيغوية وبربودية",
    "Antigua and Barbuda officials of the United Nations": "مسؤولون أنتيغويون وبربوديون في الأمم المتحدة",
    "Antigua and Barbuda people by descent": "أنتيغويون وبربوديون حسب الأصل العرقي أو الوطني",
    "Antigua and Barbuda people by occupation": "أنتيغويون وبربوديون حسب المهنة",
    "Antigua and Barbuda people by parish": "أنتيغويون وبربوديون حسب الأبرشية",
    "Antigua and Barbuda people by political orientation": "أنتيغويون وبربوديون حسب التوجه السياسي",
    "Antigua and Barbuda people by religion": "أنتيغويون وبربوديون حسب الدين",
    "Antigua and Barbuda people imprisoned abroad": "أنتيغويون وبربوديون مسجونون في الخارج",
    "Antigua and Barbuda people in sports": "أنتيغويون وبربوديون في ألعاب رياضية",
    "Antigua and Barbuda people murdered abroad": "أنتيغويون وبربوديون قتلوا في الخارج",
    "Antigua and Barbuda people of African descent": "أنتيغويون وبربوديون من أصل إفريقي",
    "Antigua and Barbuda people of American descent": "أنتيغويون وبربوديون من أصل أمريكي",
    "Antigua and Barbuda people of Anguillan descent": "أنتيغويون وبربوديون من أصل أنغويلاني",
    "Antigua and Barbuda people of Barbadian descent": "أنتيغويون وبربوديون من أصل بربادوسي",
    "Antigua and Barbuda people of British descent": "أنتيغويون وبربوديون من أصل بريطاني",
    "Antigua and Barbuda people of Caribbean descent": "أنتيغويون وبربوديون من أصل كاريبي",
    "Antigua and Barbuda people of Cuban descent": "أنتيغويون وبربوديون من أصل كوبي",
    "Antigua and Barbuda people of English descent": "أنتيغويون وبربوديون من أصل إنجليزي",
    "Antigua and Barbuda people of European descent": "أنتيغويون وبربوديون من أصل أوروبي",
    "Antigua and Barbuda people of German descent": "أنتيغويون وبربوديون من أصل ألماني",
    "Antigua and Barbuda people of Ghanaian descent": "أنتيغويون وبربوديون من أصل غاني",
    "Antigua and Barbuda people of Guyanese descent": "أنتيغويون وبربوديون من أصل غياني",
    "Antigua and Barbuda people of Indian descent": "أنتيغويون وبربوديون من أصل هندي",
    "Antigua and Barbuda people of Irish descent": "أنتيغويون وبربوديون من أصل أيرلندي",
    "Antigua and Barbuda people of Israeli descent": "أنتيغويون وبربوديون من أصل إسرائيلي",
    "Antigua and Barbuda people of Italian descent": "أنتيغويون وبربوديون من أصل إيطالي",
    "Antigua and Barbuda people of Jamaican descent": "أنتيغويون وبربوديون من أصل جامايكي",
    "Antigua and Barbuda people of Jewish descent": "أنتيغويون وبربوديون من أصل يهودي",
    "Antigua and Barbuda people of Kenyan descent": "أنتيغويون وبربوديون من أصل كيني",
    "Antigua and Barbuda people of Montserratian descent": "أنتيغويون وبربوديون من أصل مونتسراتي",
    "Antigua and Barbuda people of Nigerian descent": "أنتيغويون وبربوديون من أصل نيجيري",
    "Antigua and Barbuda people of North American descent": "أنتيغويون وبربوديون من أصل أمريكي شمالي",
    "Antigua and Barbuda people of Portuguese descent": "أنتيغويون وبربوديون من أصل برتغالي",
    "Antigua and Barbuda people of Russian descent": "أنتيغويون وبربوديون من أصل روسي",
    "Antigua and Barbuda people of Spanish descent": "أنتيغويون وبربوديون من أصل إسباني",
    "Antigua and Barbuda people of Syrian descent": "أنتيغويون وبربوديون من أصل سوري",
    "Antigua and Barbuda people of Trinidad and Tobago descent": "أنتيغويون وبربوديون من أصل ترنيدادي",
    "Antigua and Barbuda people with disabilities": "أنتيغويون وبربوديون بإعاقات",
    "Antigua and Barbuda philanthropists": "فاعلو خير أنتيغويون وبربوديون",
    "Antigua and Barbuda physicians": "أطباء أنتيغويون وبربوديون",
    "Antigua and Barbuda police officers": "ضباط شرطة أنتيغويون وبربوديون",
    "antigua and barbuda political people": "ساسة أنتيغويون وبربوديون",
    "antigua and barbuda politicians by party": "سياسيون أنتيغويون وبربوديون حسب الحزب",
    "antigua and barbuda politicians": "سياسيون أنتيغويون وبربوديون",
    "antigua and barbuda politics-related lists": "قوائم متعلقة بالسياسة الأنتيغوية والبربودية",
    "antigua and barbuda prisoners and detainees": "سجناء ومعتقلون أنتيغويون وبربوديون",
    "antigua and barbuda professional wrestlers": "مصارعون محترفون أنتيغويون وبربوديون",
    "antigua and barbuda religious leaders": "قادة دينيون أنتيغويون وبربوديون",
    "antigua and barbuda republicans": "جمهوريون أنتيغويون وبربوديون",
    "antigua and barbuda roman catholic bishops": "أساقفة كاثوليك رومان أنتيغويون وبربوديون",
    "antigua and barbuda roman catholics": "رومان كاثوليك أنتيغويون وبربوديون",
    "antigua and barbuda runners": "عداؤون أنتيغويون وبربوديون",
    "antigua and barbuda sailors (sport)": "بحارة رياضيون أنتيغويون وبربوديون",
    "antigua and barbuda singers": "مغنون أنتيغويون وبربوديون",
    "antigua and barbuda socialists": "اشتراكيون أنتيغويون وبربوديون",
    "antigua and barbuda sport by decade": "رياضة أنتيغوية وبربودية حسب العقد",
    "antigua and barbuda sport by year": "رياضة أنتيغوية وبربودية حسب السنة",
    "antigua and barbuda sport-related lists": "قوائم متعلقة برياضة أنتيغوية وبربودية",
    "antigua and barbuda sports coaches": "مدربو رياضة أنتيغويون وبربوديون",
    "antigua and barbuda sportspeople by sport": "رياضيون أنتيغويون وبربوديون حسب الرياضة",
    "antigua and barbuda sportspeople": "رياضيون أنتيغويون وبربوديون",
    "antigua and barbuda sportswomen": "رياضيات أنتيغويات وبربوديات",
    "antigua and barbuda sprinters": "عداؤون سريعون أنتيغويون وبربوديون",
    "antigua and barbuda swimmers": "سباحون أنتيغويون وبربوديون",
    "antigua and barbuda tennis players": "لاعبو كرة مضرب أنتيغويون وبربوديون",
    "antigua and barbuda triple jumpers": "لاعبو وثب ثلاثي أنتيغويون وبربوديون",
    "antigua and barbuda victims of crime": "ضحايا جرائم أنتيغويون وبربوديون",
    "antigua and barbuda windsurfers": "راكبو أمواج أنتيغويون وبربوديون",
    "antigua and barbuda women athletes": "لاعبات قوى أنتيغويات وبربوديات",
    "antigua and barbuda women by occupation": "أنتيغويات وبربوديات حسب المهنة",
    "antigua and barbuda women cricketers": "لاعبات كريكت أنتيغويات وبربوديات",
    "antigua and barbuda women high jumpers": "متسابقات قفز عالي أنتيغويات وبربوديات",
    "antigua and barbuda women illustrators": "رسامات توضيحيات أنتيغويات وبربوديات",
    "antigua and barbuda women in politics": "أنتيغويات وبربوديات في السياسة",
    "antigua and barbuda women long jumpers": "لاعبات قفز طويل أنتيغويات وبربوديات",
    "antigua and barbuda women middle-distance runners": "عداءات مسافات متوسطة أنتيغويات وبربوديات",
    "antigua and barbuda women runners": "عداءات أنتيغويات وبربوديات",
    "antigua and barbuda women sprinters": "عداءات سريعات أنتيغويات وبربوديات",
    "antigua and barbuda women writers": "كاتبات أنتيغويات وبربوديات",
    "antigua and barbuda women": "أنتيغويات وبربوديات",
    "antigua and barbuda women's national football team managers": "مدربو منتخب أنتيغوا وباربودا لكرة القدم للسيدات",
    "antigua and barbuda writers": "كتاب أنتيغويون وبربوديون",
    "antigua and barbuda–argentina relations": "العلاقات الأرجنتينية الأنتيغوية والبربودية",
    "antigua and barbuda–australia relations": "العلاقات الأسترالية الأنتيغوية والبربودية",
    "antigua and barbuda–australia sports relations": "العلاقات الأسترالية الأنتيغوية والبربودية الرياضية",
    "antigua and barbuda–barbados relations": "العلاقات الأنتيغوية والبربودية البربادوسية",
    "antigua and barbuda–belize relations": "العلاقات الأنتيغوية والبربودية البليزية",
    "antigua and barbuda–brazil relations": "العلاقات الأنتيغوية والبربودية البرازيلية",
    "antigua and barbuda–canada relations": "العلاقات الأنتيغوية والبربودية الكندية",
    "antigua and barbuda–chile relations": "العلاقات الأنتيغوية والبربودية التشيلية",
    "antigua and barbuda–china relations": "العلاقات الأنتيغوية والبربودية الصينية",
    "antigua and barbuda–colombia relations": "العلاقات الأنتيغوية والبربودية الكولومبية",
    "antigua and barbuda–cuba relations": "العلاقات الأنتيغوية والبربودية الكوبية",
    "antigua and barbuda–democratic republic of the congo relations": "العلاقات الأنتيغوية والبربودية الكونغوية الديمقراطية",
    "antigua and barbuda–dominica relations": "علاقات أنتيغوا وباربودا ودومينيكا",
    "antigua and barbuda–dominican republic relations": "العلاقات الأنتيغوية والبربودية الدومينيكانية",
    "antigua and barbuda–estonia relations": "العلاقات الأنتيغوية والبربودية الإستونية",
    "antigua and barbuda–finland relations": "العلاقات الأنتيغوية والبربودية الفنلندية",
    "antigua and barbuda–france border": "الحدود الأنتيغوية والبربودية الفرنسية",
    "antigua and barbuda–france relations": "العلاقات الأنتيغوية والبربودية الفرنسية",
    "antigua and barbuda–germany relations": "العلاقات الألمانية الأنتيغوية والبربودية",
    "antigua and barbuda–ghana relations": "العلاقات الأنتيغوية والبربودية الغانية",
    "antigua and barbuda–greece relations": "العلاقات الأنتيغوية والبربودية اليونانية",
    "antigua and barbuda–grenada relations": "العلاقات الأنتيغوية والبربودية الغرينادية",
    "antigua and barbuda–guadeloupe border": "الحدود الأنتيغوية والبربودية الغواديلوبية",
    "antigua and barbuda–guyana relations": "العلاقات الأنتيغوية والبربودية الغيانية",
    "antigua and barbuda–haiti relations": "العلاقات الأنتيغوية والبربودية الهايتية",
    "antigua and barbuda–india relations": "العلاقات الأنتيغوية والبربودية الهندية",
    "antigua and barbuda–india sports relations": "العلاقات الأنتيغوية والبربودية الهندية الرياضية",
    "antigua and barbuda–ireland relations": "العلاقات الأنتيغوية والبربودية الأيرلندية",
    "antigua and barbuda–israel relations": "العلاقات الأنتيغوية والبربودية الإسرائيلية",
    "antigua and barbuda–italy relations": "العلاقات الأنتيغوية والبربودية الإيطالية",
    "antigua and barbuda–jamaica relations": "العلاقات الأنتيغوية والبربودية الجامايكية",
    "antigua and barbuda–japan relations": "العلاقات الأنتيغوية والبربودية اليابانية",
    "antigua and barbuda–kenya relations": "العلاقات الأنتيغوية والبربودية الكينية",
    "antigua and barbuda–mexico relations": "العلاقات الأنتيغوية والبربودية المكسيكية",
    "antigua and barbuda–netherlands relations": "العلاقات الأنتيغوية والبربودية الهولندية",
    "antigua and barbuda–new zealand relations": "العلاقات الأنتيغوية والبربودية النيوزيلندية",
    "antigua and barbuda–nigeria relations": "العلاقات الأنتيغوية والبربودية النيجيرية",
    "antigua and barbuda–paraguay relations": "العلاقات الأنتيغوية والبربودية البارغوايانية",
    "antigua and barbuda–peru relations": "العلاقات الأنتيغوية والبربودية البيروية",
    "antigua and barbuda–poland relations": "العلاقات الأنتيغوية والبربودية البولندية",
    "antigua and barbuda–portugal relations": "العلاقات الأنتيغوية والبربودية البرتغالية",
    "antigua and barbuda–russia relations": "العلاقات الأنتيغوية والبربودية الروسية",
    "antigua and barbuda–saint kitts and nevis relations": "علاقات أنتيغوا وباربودا وسانت كيتس ونيفيس",
    "antigua and barbuda–saint lucia relations": "علاقات أنتيغوا وباربودا وسانت لوسيا",
    "antigua and barbuda–saint vincent and the grenadines relations": "علاقات أنتيغوا وباربودا وسانت فنسنت وجزر غرينادين",
    "antigua and barbuda–south africa relations": "العلاقات الأنتيغوية والبربودية الجنوب الإفريقية",
    "antigua and barbuda–south africa sports relations": "العلاقات الأنتيغوية والبربودية الجنوب الإفريقية الرياضية",
    "antigua and barbuda–spain relations": "العلاقات الأنتيغوية والبربودية الإسبانية",
    "antigua and barbuda–syria relations": "العلاقات الأنتيغوية والبربودية السورية",
    "antigua and barbuda–trinidad and tobago relations": "العلاقات الأنتيغوية والبربودية الترنيدادية",
    "antigua and barbuda–turkey relations": "العلاقات الأنتيغوية والبربودية التركية",
    "antigua and barbuda–ukraine relations": "العلاقات الأنتيغوية والبربودية الأوكرانية",
    "antigua and barbuda–united kingdom sports relations": "العلاقات الأنتيغوية والبربودية البريطانية الرياضية",
    "Antigua and Barbuda–Ukraine relations": "العلاقات الأنتيغوية والبربودية الأوكرانية",
    "Antigua and Barbuda–United Kingdom relations": "العلاقات الأنتيغوية والبربودية البريطانية",
    "Antigua and Barbuda–United Kingdom sports relations": "العلاقات الأنتيغوية والبربودية البريطانية الرياضية",
    "Antigua and Barbuda–United States relations": "العلاقات الأمريكية الأنتيغوية والبربودية",
    "Antigua and Barbuda–United States sports relations": "العلاقات الأمريكية الأنتيغوية والبربودية الرياضية",
    "Antigua and Barbuda–Venezuela relations": "العلاقات الأنتيغوية والبربودية الفنزويلية",
    "Argentine expatriate sportspeople in Antigua and Barbuda": "رياضيون أرجنتينيون مغتربون في أنتيغوا وباربودا",
    "Argentine expatriates in Antigua and Barbuda": "أرجنتينيون مغتربون في أنتيغوا وباربودا",
    "Arts festivals in Antigua and Barbuda": "مهرجانات فنية في أنتيغوا وباربودا",
    "Arts organisations based in Antigua and Barbuda": "منظمات فنية مقرها في أنتيغوا وباربودا",
    "Athletics in Antigua and Barbuda": "ألعاب القوى في أنتيغوا وباربودا",
    "Athletics venues in Antigua and Barbuda": "ملاعب ألعاب القوى في أنتيغوا وباربودا",
    "Attorneys general of Antigua and Barbuda": "مدعون عامون من أنتيغوا وباربودا",
    "Australian expatriates in Antigua and Barbuda": "أستراليون مغتربون في أنتيغوا وباربودا",
    "Australian people of Antigua and Barbuda descent": "أستراليون من أصل أنتيغوي وبربودي",
    "Aviation accidents and incidents in Antigua and Barbuda": "حوادث طيران في أنتيغوا وباربودا",
    "Banks of Antigua and Barbuda": "بنوك أنتيغوا وباربودا",
    "Beaches of Antigua and Barbuda": "شواطئ أنتيغوا وباربودا",
    "Bermudian expatriates in Antigua and Barbuda": "برموديون مغتربون في أنتيغوا وباربودا",
    "Bermudian people of Antigua and Barbuda descent": "برموديون من أصل أنتيغوي وبربودي",
    "Biology in Antigua and Barbuda": "علم الأحياء في أنتيغوا وباربودا",
    "Birds of Antigua and Barbuda": "طيور أنتيغوا وباربودا",
    "Bodies of water of Antigua and Barbuda": "مسطحات مائية في أنتيغوا وباربودا",
    "Borders of Antigua and Barbuda": "حدود أنتيغوا وباربودا",
    "British emigrants to Antigua and Barbuda": "بريطانيون مهاجرون إلى أنتيغوا وباربودا",
    "Business organisations based in Antigua and Barbuda": "منظمات أعمال مقرها في أنتيغوا وباربودا",
    "Canadian people of Antigua and Barbuda descent": "كنديون من أصل أنتيغوي وبربودي",
    "Canoeing in Antigua and Barbuda": "ركوب الكنو في أنتيغوا وباربودا",
    "Cargo ships of Antigua and Barbuda": "سفن بضائع أنتيغوا وباربودا",
    "Carnivals in Antigua and Barbuda": "كرنفالات في أنتيغوا وباربودا",
    "Cathedrals in Antigua and Barbuda": "كاتدرائيات في أنتيغوا وباربودا",
    "Central American and Caribbean Games bronze medalists for Antigua and Barbuda": "فائزون بميداليات برونزية في ألعاب أمريكا الوسطى والكاريبي من أنتيغوا وباربودا",
    "Christian missionaries in Antigua and Barbuda": "مبشرون مسيحيون في أنتيغوا وباربودا",
    "Churches in Antigua and Barbuda": "كنائس في أنتيغوا وباربودا",
    "Companies of Antigua and Barbuda": "شركات في أنتيغوا وباربودا",
    "Constituencies of Antigua and Barbuda": "دوائر إنتخابية في أنتيغوا وباربودا",
    "Cricket in Antigua and Barbuda": "الكريكت في أنتيغوا وباربودا",
    "Cricket teams in Antigua and Barbuda": "فرق الكريكت في أنتيغوا وباربودا",
    "Crime in Antigua and Barbuda": "جريمة في أنتيغوا وباربودا",
    "Cultural festivals in Antigua and Barbuda": "مهرجانات ثقافية في أنتيغوا وباربودا",
    "Cycle racing in Antigua and Barbuda": "سباق دراجات في أنتيغوا وباربودا",
    "Cycling in Antigua and Barbuda": "ركوب الدراجات في أنتيغوا وباربودا",
    "Dams in Antigua and Barbuda": "سدود في أنتيغوا وباربودا",
    "Death in Antigua and Barbuda": "الموت في أنتيغوا وباربودا",
    "Deaths by firearm in Antigua and Barbuda": "وفيات بإطلاق النار في أنتيغوا وباربودا",
    "Deaths in Antigua and Barbuda": "وفيات في أنتيغوا وباربودا",
    "Defunct airlines of Antigua and Barbuda": "شركات طيران سابقة في أنتيغوا وباربودا",
    "Defunct banks of Antigua and Barbuda": "بنوك سابقة في أنتيغوا وباربودا",
    "Defunct companies of Antigua and Barbuda": "شركات سابقة في أنتيغوا وباربودا",
    "Defunct organisations based in Antigua and Barbuda": "منظمات سابقة مقرها في أنتيغوا وباربودا",
    "Defunct political parties in Antigua and Barbuda": "أحزاب سياسية سابقة في أنتيغوا وباربودا",
    "Democratic Republic of the Congo expatriate sportspeople in Antigua and Barbuda": "رياضيون كونغويون ديمقراطيون مغتربون في أنتيغوا وباربودا",
    "Democratic Republic of the Congo expatriates in Antigua and Barbuda": "كونغويون ديمقراطيون مغتربون في أنتيغوا وباربودا",
    "Demographics by parish in Antigua and Barbuda": "التركيبة السكانية حسب الأبرشية في أنتيغوا وباربودا",
    "Diplomatic missions of Antigua and Barbuda": "بعثات أنتيغوا وباربودا الدبلوماسية",
    "Disestablishments in Antigua and Barbuda by century": "انحلالات في أنتيغوا وباربودا حسب القرن",
    "Disestablishments in Antigua and Barbuda by decade": "انحلالات في أنتيغوا وباربودا حسب العقد",
    "Disestablishments in Antigua and Barbuda by millennium": "انحلالات في أنتيغوا وباربودا حسب الألفية",
    "Disestablishments in Antigua and Barbuda by year": "انحلالات في أنتيغوا وباربودا حسب السنة",
    "Dominican Republic expatriates in Antigua and Barbuda": "دومينيكانيون مغتربون في أنتيغوا وباربودا",
    "Education in Antigua and Barbuda": "التعليم في أنتيغوا وباربودا",
    "Educational organisations based in Antigua and Barbuda": "منظمات تعليمية مقرها في أنتيغوا وباربودا",
    "Elections in Antigua and Barbuda": "انتخابات في أنتيغوا وباربودا",
    "Festivals in Antigua and Barbuda": "مهرجانات في أنتيغوا وباربودا",
    "Films shot in Antigua and Barbuda": "أفلام مصورة في أنتيغوا وباربودا",
    "Financial services companies of Antigua and Barbuda": "شركات خدمات مالية في أنتيغوا وباربودا",
    "Financial services in Antigua and Barbuda": "خدمات مالية في أنتيغوا وباربودا",
    "Food and drink in Antigua and Barbuda": "أطعمة ومشروبات في أنتيغوا وباربودا",
    "Football clubs in Antigua and Barbuda": "أندية كرة قدم في أنتيغوا وباربودا",
    "Footballers in Antigua and Barbuda by club": "لاعبو كرة قدم في أنتيغوا وباربودا حسب النادي",
    "Fortifications in Antigua and Barbuda": "تحصينات في أنتيغوا وباربودا",
    "Forts in Antigua and Barbuda": "حصون في أنتيغوا وباربودا",
    "Gambling in Antigua and Barbuda": "مقامرة في أنتيغوا وباربودا",
    "Geology of Antigua and Barbuda": "جيولوجيا أنتيغوا وباربودا",
    "German expatriate sportspeople in Antigua and Barbuda": "رياضيون ألمان مغتربون في أنتيغوا وباربودا",
    "German expatriates in Antigua and Barbuda": "ألمان مغتربون في أنتيغوا وباربودا",
    "Ghanaian expatriates in Antigua and Barbuda": "غانيون مغتربون في أنتيغوا وباربودا",
    "Government ministries of Antigua and Barbuda": "وزارات حكومة أنتيغوا وباربودا",
    "Grenadian expatriate sportspeople in Antigua and Barbuda": "رياضيون غريناديون مغتربون في أنتيغوا وباربودا",
    "Grenadian expatriates in Antigua and Barbuda": "غريناديون مغتربون في أنتيغوا وباربودا",
    "Guyanese emigrants to Antigua and Barbuda": "غيانيون مهاجرون إلى أنتيغوا وباربودا",
    "Guyanese expatriate sportspeople in Antigua and Barbuda": "رياضيون غيانيون مغتربون في أنتيغوا وباربودا",
    "Guyanese expatriates in Antigua and Barbuda": "غيانيون مغتربون في أنتيغوا وباربودا",
    "Guyanese people of Antigua and Barbuda descent": "غيانيون من أصل أنتيغوي وبربودي",
    "Healthcare in Antigua and Barbuda": "الرعاية الصحية في أنتيغوا وباربودا",
    "Heritage registers in Antigua and Barbuda": "سجلات التراث في أنتيغوا وباربودا",
    "Historic sites in Antigua and Barbuda": "مواقع تاريخية في أنتيغوا وباربودا",
    "History of British Antigua and Barbuda": "تاريخ أنتيغويون وبربوديون بريطانيون",
    "History of football in Antigua and Barbuda": "تاريخ كرة القدم في أنتيغوا وباربودا",
    "Indian people of Antigua and Barbuda descent": "هنود من أصل أنتيغوي وبربودي",
    "Insects of Antigua and Barbuda": "حشرات أنتيغوا وباربودا",
    "International association football competitions hosted by Antigua and Barbuda": "منافسات كرة قدم دولية استضافتها أنتيغوا وباربودا",
    "International sports competitions hosted by Antigua and Barbuda": "منافسات رياضية دولية استضافتها أنتيغوا وباربودا",
    "Irish people of Antigua and Barbuda descent": "أيرلنديون من أصل أنتيغوي وبربودي",
    "Jamaican emigrants to Antigua and Barbuda": "جامايكيون مهاجرون إلى أنتيغوا وباربودا",
    "Jamaican people of Antigua and Barbuda descent": "جامايكيون من أصل أنتيغوي وبربودي",
    "Judiciary of Antigua and Barbuda": "النظام القضائي أنتيغوا وباربودا",
    "Labour relations in Antigua and Barbuda": "علاقات عمالية في أنتيغوا وباربودا",
    "Landmarks in Antigua and Barbuda": "معالم في أنتيغوا وباربودا",
    "Law enforcement in Antigua and Barbuda": "تطبيق القانون في أنتيغوا وباربودا",
    "Lebanese people of Antigua and Barbuda descent": "لبنانيون من أصل أنتيغوي وبربودي",
    "Libraries in Antigua and Barbuda": "مكتبات في أنتيغوا وباربودا",
    "Lists of ambassadors of Antigua and Barbuda": "قوائم سفراء أنتيغوا وباربودا",
    "Lists of ambassadors to Antigua and Barbuda": "قوائم سفراء لدى أنتيغوا وباربودا",
    "Lists of Antigua and Barbuda people by occupation": "قوائم أنتيغويون وبربوديون حسب المهنة",
    "Lists of Antigua and Barbuda sportspeople": "قوائم رياضيون أنتيغويون وبربوديون",
    "Lists of biota of Antigua and Barbuda": "قوائم حيويات أنتيغوا وباربودا",
    "Lists of buildings and structures in Antigua and Barbuda": "قوائم مبان ومنشآت في أنتيغوا وباربودا",
    "Lists of religious buildings and structures in Antigua and Barbuda": "قوائم مبان ومنشآت دينية في أنتيغوا وباربودا",
    "Lists of tourist attractions in Antigua and Barbuda": "قوائم مواقع جذب سياحي في أنتيغوا وباربودا",
    "Local government in Antigua and Barbuda": "الحكومة المحلية في أنتيغوا وباربودا",
    "Mass media in Antigua and Barbuda": "وسائل إعلام في أنتيغوا وباربودا",
    "Medical and health organisations based in Antigua and Barbuda": "منظمات طبية وصحية مقرها في أنتيغوا وباربودا",
    "Medical schools in Antigua and Barbuda": "مدارس طبية في أنتيغوا وباربودا",
    "Medicine in Antigua and Barbuda": "الطب في أنتيغوا وباربودا",
    "Members of the Parliament of Antigua and Barbuda": "أعضاء برلمان أنتيغوا وباربودا",
    "Members of the Parliament of Antigua and Barbuda by term": "أعضاء برلمان أنتيغوا وباربودا حسب الفترة",
    "Members of the Senate (Antigua and Barbuda)": "أعضاء مجلس الشيوخ (أنتيغوا وباربودا)",
    "Military equipment of Antigua and Barbuda": "عتاد أنتيغوا وباربودا العسكري",
    "Montserratian emigrants to Antigua and Barbuda": "مونتسراتيون مهاجرون إلى أنتيغوا وباربودا",
    "Montserratian expatriates in Antigua and Barbuda": "مونتسراتيون مغتربون في أنتيغوا وباربودا",
    "Montserratian people of Antigua and Barbuda descent": "مونتسراتيون من أصل أنتيغوي وبربودي",
    "Museums in Antigua and Barbuda": "متاحف في أنتيغوا وباربودا",
    "Music festivals in Antigua and Barbuda": "مهرجانات موسيقية في أنتيغوا وباربودا",
    "Music of Antigua and Barbuda": "موسيقى أنتيغوا وباربودا",
    "Music organisations based in Antigua and Barbuda": "منظمات موسيقى مقرها في أنتيغوا وباربودا",
    "National parks of Antigua and Barbuda": "متنزهات وطنية في أنتيغوا وباربودا",
    "Naval ships of Antigua and Barbuda": "سفن قوات بحرية في أنتيغوا وباربودا",
    "Newspapers published in Antigua and Barbuda": "صحف نشرت في أنتيغوا وباربودا",
    "Nigerian expatriates in Antigua and Barbuda": "نيجيريون مغتربون في أنتيغوا وباربودا",
    "Nigerian people of Antigua and Barbuda descent": "نيجيريون من أصل أنتيغوي وبربودي",
    "Olympic boxers for Antigua and Barbuda": "ملاكمون أولمبيون في أنتيغوا وباربودا",
    "Olympic canoeists for Antigua and Barbuda": "متسابقو قوارب الكانوي أولمبيون في أنتيغوا وباربودا",
    "Olympic cyclists for Antigua and Barbuda": "دراجون أولمبيون في أنتيغوا وباربودا",
    "Orders, decorations, and medals of Antigua and Barbuda": "مراتب تشريفية وأوسمة وميداليات أنتيغوا وباربودا",
    "Pan American Games bronze medalists for Antigua and Barbuda": "فائزون بميداليات برونزية في دورة الألعاب الأمريكية من أنتيغوا وباربودا",
    "Pan American Games gold medalists for Antigua and Barbuda": "فائزون بميداليات ذهبية في دورة الألعاب الأمريكية من أنتيغوا وباربودا",
    "Pan American Games medalists for Antigua and Barbuda": "فائزون بميداليات دورة الألعاب الأمريكية من أنتيغوا وباربودا",
    "Pan American Games silver medalists for Antigua and Barbuda": "فائزون بميداليات فضية في دورة الألعاب الأمريكية من أنتيغوا وباربودا",
    "Paralympic athletes for Antigua and Barbuda": "لاعبو قوى في الألعاب البارالمبية في أنتيغوا وباربودا",
    "People murdered in Antigua and Barbuda": "أشخاص قتلوا في أنتيغوا وباربودا",
    "Permanent delegates of Antigua and Barbuda to UNESCO": "مندوبو أنتيغوا وباربودا الدائمون لدى يونسكو",
    "Permanent representatives of Antigua and Barbuda to the Organization of American States": "مندوبو أنتيغوا وباربودا الدائمون إلى منظمة الدول الأمريكية",
    "Political history of Antigua and Barbuda": "تاريخ أنتيغوا وباربودا السياسي",
    "Political movements in Antigua and Barbuda": "حركات سياسية في أنتيغوا وباربودا",
    "Presidents of the Senate (Antigua and Barbuda)": "رؤساء مجلس الشيوخ (أنتيغوا وباربودا)",
    "Professional wrestling in Antigua and Barbuda": "مصارعة المحترفين في أنتيغوا وباربودا",
    "Protected areas of Antigua and Barbuda": "مناطق محمية في أنتيغوا وباربودا",
    "Protestant missionaries in Antigua and Barbuda": "مبشرون بروتستانتيون في أنتيغوا وباربودا",
    "Protestantism in Antigua and Barbuda": "البروتستانتية في أنتيغوا وباربودا",
    "Public holidays in Antigua and Barbuda": "عطلات رسمية في أنتيغوا وباربودا",
    "Recipients of orders, decorations, and medals of Antigua and Barbuda": "حاصلون على مراتب تشريفية وأوسمة وميداليات أنتيغوا وباربودا",
    "Referendums in Antigua and Barbuda": "استفتاءات في أنتيغوا وباربودا",
    "Religious buildings and structures in Antigua and Barbuda": "مبان ومنشآت دينية في أنتيغوا وباربودا",
    "Religious festivals in Antigua and Barbuda": "مهرجانات دينية في أنتيغوا وباربودا",
    "Religious organisations based in Antigua and Barbuda": "منظمات دينية مقرها في أنتيغوا وباربودا",
    "Reptiles of Antigua and Barbuda": "زواحف أنتيغوا وباربودا",
    "Rivers of Antigua and Barbuda": "أنهار أنتيغوا وباربودا",
    "Road transport in Antigua and Barbuda": "نقل بري في أنتيغوا وباربودا",
    "Rugby union in Antigua and Barbuda": "اتحاد الرجبي في أنتيغوا وباربودا",
    "Running in Antigua and Barbuda": "ركض في أنتيغوا وباربودا",
    "Sailing competitions in Antigua and Barbuda": "منافسات إبحار في أنتيغوا وباربودا",
    "Sailing in Antigua and Barbuda": "الإبحار في أنتيغوا وباربودا",
    "Schools in Antigua and Barbuda": "مدارس في أنتيغوا وباربودا",
    "Science and technology in Antigua and Barbuda": "العلوم والتقانة في أنتيغوا وباربودا",
    "Scottish people of Antigua and Barbuda descent": "إسكتلنديون من أصل أنتيغوي وبربودي",
    "Seasons in Antigua and Barbuda sport": "مواسم في رياضة أنتيغوية وبربودية",
    "Service companies of Antigua and Barbuda": "شركات خدمات في أنتيغوا وباربودا",
    "Ships of Antigua and Barbuda": "سفن أنتيغوا وباربودا",
    "Spanish people of Antigua and Barbuda descent": "إسبان من أصل أنتيغوي وبربودي",
    "Sportspeople of Antigua and Barbuda descent": "رياضيون من أصل أنتيغوي وبربودي",
    "Telecommunications in Antigua and Barbuda": "الاتصالات عن بعد في أنتيغوا وباربودا",
    "Television shows filmed in Antigua and Barbuda": "عروض تلفزيونية صورت في أنتيغوا وباربودا",
    "Tennis tournaments in Antigua and Barbuda": "بطولات كرة مضرب في أنتيغوا وباربودا",
    "Towns in Antigua and Barbuda": "بلدات في أنتيغوا وباربودا",
    "Trade unions in Antigua and Barbuda": "نقابات عمالية في أنتيغوا وباربودا",
    "Transport disasters in Antigua and Barbuda": "كوارث نقل في أنتيغوا وباربودا",
    "Transport organisations based in Antigua and Barbuda": "منظمات نقل مقرها في أنتيغوا وباربودا",
    "Treaties extended to British Antigua and Barbuda": "اتفاقيات امتدت إلى أنتيغويون وبربوديون بريطانيون",
    "Trinidad and Tobago expatriate sportspeople in Antigua and Barbuda": "رياضيون ترنيداديون مغتربون في أنتيغوا وباربودا",
    "Trinidad and Tobago expatriates in Antigua and Barbuda": "ترنيداديون مغتربون في أنتيغوا وباربودا",
    "Turkish people of Antigua and Barbuda descent": "أتراك من أصل أنتيغوي وبربودي",
    "Universities and colleges in Antigua and Barbuda": "جامعات وكليات في أنتيغوا وباربودا",
    "Universities in Antigua and Barbuda": "جامعات في أنتيغوا وباربودا",
    "Violence in Antigua and Barbuda": "عنف في أنتيغوا وباربودا",
    "Violent deaths in Antigua and Barbuda": "وفيات عنيفة في أنتيغوا وباربودا",
    "Water transport in Antigua and Barbuda": "نقل مائي في أنتيغوا وباربودا",
    "Weightlifting in Antigua and Barbuda": "رفع الأثقال في أنتيغوا وباربودا",
    "Welsh people of Antigua and Barbuda descent": "ويلزيون من أصل أنتيغوي وبربودي",
    "West German expatriate sportspeople in Antigua and Barbuda": "رياضيون ألمانيون غربيون مغتربون في أنتيغوا وباربودا",
    "West German expatriates in Antigua and Barbuda": "ألمانيون غربيون مغتربون في أنتيغوا وباربودا",
    "Wetlands of Antigua and Barbuda": "مناطق رطبة في أنتيغوا وباربودا",
    "Women's cricket in Antigua and Barbuda": "الكريكت للسيدات في أنتيغوا وباربودا",
    "Years in Antigua and Barbuda by month": "سنوات في أنتيغوا وباربودا حسب الشهر",
    "Youth in Antigua and Barbuda": "الشباب في أنتيغوا وباربودا",
    "Youth organisations based in Antigua and Barbuda": "منظمات شبابية مقرها في أنتيغوا وباربودا",
    "Youth sport in Antigua and Barbuda": "رياضة شبابية في أنتيغوا وباربودا",
}

to_test = [
    ("test_antigua_and_barbuda_0", data_0),
    ("test_antigua_and_barbuda_1", data_1),
]


@pytest.mark.parametrize("category, expected", data_0.items(), ids=data_0.keys())
@pytest.mark.fast
def test_antigua_and_barbuda_0(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


@pytest.mark.parametrize("category, expected", data_1.items(), ids=data_1.keys())
@pytest.mark.fast
def test_antigua_and_barbuda_1(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)
    dump_diff(diff_result, name)
    # dump_diff_text(expected, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"


@pytest.mark.parametrize("name,data", [("test_antigua_and_barbuda_data_skip", data_skip)])
@pytest.mark.skip2
def test_dump_it_skip2(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)
    dump_diff(diff_result, name)
    # dump_diff_text(expected, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_label_ar

test_skip = {"Jewish-American history in New York City": ""}

examples_1 = {
    "Ministers for foreign affairs of Papua New Guinea": "وزراء شؤون خارجية بابوا غينيا الجديدة",
    "Justice ministers of Papua New Guinea": "وزراء عدل بابوا غينيا الجديدة",
    "Women government ministers of Antigua and Barbuda": "وزيرات أنتيغويات وبربوديات",
    "Agriculture ministers of Antigua and Barbuda": "وزراء زراعة أنتيغوا وباربودا",
    "Energy ministers of Antigua and Barbuda": "وزراء طاقة أنتيغوا وباربودا",
    "Tourism ministers of Antigua and Barbuda": "وزراء سياحة أنتيغوا وباربودا",
    "Trade ministers of Antigua and Barbuda": "وزراء تجارة أنتيغوا وباربودا",
    "Culture ministers of Uganda": "وزراء ثقافة أوغندا",
    "Defence ministers of Kuwait": "وزراء دفاع الكويت",
    "Education ministers of Afghanistan": "وزراء تعليم أفغانستان",
    "Finance ministers of Tunisia": "وزراء مالية تونس",
    "Foreign ministers of South Sudan": "وزراء خارجية جنوب السودان",
    "Labour ministers of Chad": "وزراء عمل تشاد",
    "Ministers for foreign affairs of Ireland": "وزراء شؤون خارجية أيرلندا",
    "Trade ministers of Indonesia": "وزراء تجارة إندونيسيا",
    "Transport ministers of Argentina": "وزراء نقل الأرجنتين",
    "Transport ministers of Liberia": "وزراء نقل ليبيريا",
    "Foreign trade ministers of Netherlands": "وزراء تجارة خارجية هولندا",
    "Social affairs ministers of Uganda": "وزراء شؤون اجتماعية أوغندا",
    "Trade ministers of Togo": "وزراء تجارة توغو",
    "Ministers for Foreign Affairs of Abkhazia": "وزراء شؤون خارجية أبخازيا",
    "Ministers for Foreign Affairs of Singapore": "وزراء شؤون خارجية سنغافورة",
    "Ministers for Foreign Affairs of Luxembourg": "وزراء شؤون خارجية لوكسمبورغ",
    "Ministers for Internal Affairs of Abkhazia": "وزراء شؤون داخلية أبخازيا",
    "Ministers for Public Works of Luxembourg": "وزراء أشغال عامة لوكسمبورغ",
    "Housing ministers of Abkhazia": "وزراء إسكان أبخازيا",
    "Economy ministers of Latvia": "وزراء اقتصاد لاتفيا",
    "Ministers of Economics of Latvia": "وزراء الاقتصاد في لاتفيا",
    "Religious affairs ministers of Yemen": "وزراء شؤون دينية اليمن",
}

examples_2 = {
    "Agriculture ministers of Azerbaijan": "وزراء زراعة أذربيجان",
    "Agriculture ministers of Maldives": "وزراء زراعة جزر المالديف",
    "Communications ministers of Azerbaijan": "وزراء اتصالات أذربيجان",
    "Communications ministers of Comoros": "وزراء اتصالات جزر القمر",
    "Culture ministers of Gabon": "وزراء ثقافة الغابون",
    "Education ministers of Comoros": "وزراء تعليم جزر القمر",
    "Electricity and water ministers of Somalia": "وزراء كهرباء ومياه الصومال",
    "Energy ministers of Gabon": "وزراء طاقة الغابون",
    "Finance ministers of Burundi": "وزراء مالية بوروندي",
    "Health ministers of Comoros": "وزراء صحة جزر القمر",
    "Industry ministers of Togo": "وزراء صناعة توغو",
    "Interior ministers of Uganda": "وزراء داخلية أوغندا",
    "Justice ministers of Djibouti": "وزراء عدل جيبوتي",
    "Justice ministers of Comoros": "وزراء عدل جزر القمر",
    "Justice ministers of Gambia": "وزراء عدل غامبيا",
    "Labour ministers of Gabon": "وزراء عمل الغابون",
    "Labour ministers of Sudan": "وزراء عمل السودان",
    "Labour ministers of Comoros": "وزراء عمل جزر القمر",
    "Ministers for culture of Abkhazia": "وزراء ثقافة أبخازيا",
    "Oil ministers of Gabon": "وزراء بترول الغابون",
    "Planning ministers of Comoros": "وزراء تخطيط جزر القمر",
    "Transport ministers of Gabon": "وزراء نقل الغابون",
    "Science ministers of Spain": "وزراء العلم إسبانيا",
    "Water ministers of Mauritania": "وزراء مياه موريتانيا",
    "Ministers of Housing of Abkhazia": "وزراء إسكان أبخازيا",
    "Ministers of Religious Affairs of the Netherlands": "وزراء شؤون دينية هولندا",
    "Women government ministers of Latvia": "وزيرات لاتفيات",
    "Women's ministers of Fiji": "وزيرات فيجي",
    "Ministers of Labour and Social Security of Turkey": "وزراء عمل وضمان اجتماعي تركيا",
}

TEMPORAL_CASES = [
    ("test_ministers_1", examples_1),
    ("test_ministers_2", examples_2),
]


@pytest.mark.parametrize("category, expected", examples_1.items(), ids=examples_1.keys())
@pytest.mark.fast
def test_ministers_1(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", examples_2.items(), ids=examples_2.keys())
@pytest.mark.fast
def test_ministers_2(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("name,data", TEMPORAL_CASES)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""Tests for :mod:`legacy_bots.o_bots.bys`."""

from __future__ import annotations

import pytest

from ArWikiCats.legacy_bots.o_bots import bys


@pytest.mark.unit
def test_make_by_label_prefers_film_labels(monkeypatch: pytest.MonkeyPatch) -> None:
    monkeypatch.setattr(
        "ArWikiCats.legacy_bots.o_bots.bys.te_films",
        lambda name: {"The Matrix": "فيلم"}.get(name, ""),
    )

    result = bys.make_by_label("by The Matrix")
    assert result == "بواسطة فيلم"


@pytest.mark.unit
def test_make_by_label_falls_back_to_nationality(monkeypatch: pytest.MonkeyPatch) -> None:
    monkeypatch.setattr(
        "ArWikiCats.legacy_bots.o_bots.bys.te_films",
        lambda name: {"Ali": "مصري"}.get(name, ""),
    )

    result = bys.make_by_label("by Ali")
    assert result == "بواسطة مصري"


@pytest.mark.unit
def test_find_dual_by_keys_supports_dual_categories(monkeypatch: pytest.MonkeyPatch) -> None:
    monkeypatch.setattr(
        "ArWikiCats.legacy_bots.o_bots.bys.resolve_by_labels",
        lambda name: {"alpha": "ألفا", "beta": "بيتا"}.get(name, ""),
    )

    result = bys.find_dual_by_keys("by alpha and beta")
    assert result == "حسب ألفا وبيتا"


@pytest.mark.unit
def test_get_by_label_combines_entity_and_suffix(monkeypatch: pytest.MonkeyPatch) -> None:
    monkeypatch.setattr(
        "ArWikiCats.legacy_bots.o_bots.bys.resolve_by_labels",
        lambda name: {"by birth": "حسب الميلاد"}.get(name, ""),
    )
    monkeypatch.setattr(
        "ArWikiCats.legacy_bots.o_bots.bys.get_from_new_p17_final",
        lambda name: {"artist": "فنان"}.get(name, ""),
    )

    result = bys.get_by_label("Artist by birth")
    assert result == "فنان حسب الميلاد"


@pytest.mark.unit
def test_get_and_label_returns_joined_entities(monkeypatch: pytest.MonkeyPatch) -> None:
    monkeypatch.setattr(
        "ArWikiCats.legacy_bots.o_bots.bys.get_from_new_p17_final",
        lambda name, _: {"artist": "فنان", "painter": "رسام"}.get(name, ""),
    )

    result = bys.get_and_label("Artist and Painter")
    assert result == "فنان ورسام"



"""Tests for :mod:`make_bots.o_bots.bys`."""

from __future__ import annotations

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.legacy_bots.o_bots.bys import make_new_by_label

make_new_by_label_data = {
    "by ali khamenei": "بواسطة علي خامنئي",
}

to_test = [
    ("test_make_new_by_label", make_new_by_label_data, make_new_by_label),
]


@pytest.mark.parametrize("category, expected", make_new_by_label_data.items(), ids=make_new_by_label_data.keys())
@pytest.mark.fast
def test_make_new_by_label(category: str, expected: str) -> None:
    label = make_new_by_label(category)
    assert label == expected, f"Failed for category: {category}"


@pytest.mark.parametrize("name,data, callback", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)
    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
